#
# spec file for package git-cola
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Marcin Bajor
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           git-cola
Version:        4.8.0
Release:        1.3
Summary:        A GUI for Git
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
URL:            https://git-cola.github.io/
Source:         https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-Sphinx
BuildRequires:  python3-build
BuildRequires:  python3-jaraco.packaging
BuildRequires:  python3-pip
BuildRequires:  python3-qt6
BuildRequires:  python3-rst.linker
BuildRequires:  python3-setuptools_scm
BuildRequires:  python3-wheel
BuildRequires:  update-desktop-files
Requires:       git-core
Requires:       python3-QtPy
Requires:       python3-qt6
Recommends:     gitk
Recommends:     python3-Send2Trash
Recommends:     python3-pyinotify
BuildArch:      noarch

%description
git-cola is a graphical user interface for Git that provides a way to
interact with Git repositories.

%prep
%setup -q

%build

python3 -m build --wheel --no-isolation

%make_build man prefix=%{_prefix} DESTDIR=%{buildroot} PYTHON=python3 PIP=pip

%install

pip install --no-deps --force-reinstall  --root=%{buildroot} --prefix="%{_prefix}" dist/*.whl

make install-man prefix=%{_prefix} DESTDIR=%{buildroot} PYTHON=python3 PIP=pip

%suse_update_desktop_file %{buildroot}%{_datadir}/applications/git-cola.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/git-dag.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/git-cola-folder-handler.desktop

%files
%license COPYING COPYRIGHT
%{_bindir}/cola
%{_bindir}/git-cola
%{_bindir}/git-dag
%{_bindir}/git-cola-sequence-editor
%{_datadir}/applications/git-cola.desktop
%{_datadir}/applications/git-dag.desktop
%{_datadir}/applications/git-cola-folder-handler.desktop
%{_datadir}/metainfo/git-cola.appdata.xml
%{_datadir}/metainfo/git-dag.appdata.xml
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/scalable
%dir %{_datadir}/icons/hicolor/scalable/apps
%{_datadir}/icons/hicolor/scalable/apps/git-cola.svg
%dir %{_datadir}/doc/git-cola
%{_datadir}/doc/git-cola/*
%{_mandir}/man1/*.*
%if 0%{?sles_version} > 9
%{_datadir}/locale/zh_cn
%endif
%dir %{python3_sitelib}/cola
%{python3_sitelib}/cola/*
%{python3_sitelib}/git_cola*

%changelog
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 4.8.0:
  * The Rebase editor is now aware of the drop, break, label,
    merge and reset commands that were added in recent versions
    of Git.
  * Desktop notifications can now be enabled when pushing remotes
    by enabling the "Notify on Push" option in the preferences.
  * Faster and easier commit hash copying in DAG. Left-clicking
    on the Commit ID will now copy it directly into the clipboard
    without any further action.
  * "Grab File from Parent Commit" actions have been added to the
    DAG.
  * The Unstage Selected action was added to the context menu for
    unmerged files.
  * git cola rebase now provides  a --rebase-merges option and
    passes the same option to git rebase when Git v1.18.0 or
    newer is detected.
  * Pre-commits hooks were updated.
* Sun May  5 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 4.7.1:
  * The Fetch dialog can now fetch directly into a remote tracking
    branch
  * The Fetch, Push and Pull dialogs now remember the selected
    remotes, and now display the git commands that will be run.
  * The Pull dialog now selects the remote branch automatically.
  * The cola.refreshonfocus and cola.inotify configuration settings
    are now accessible from the git cola config settings dialog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 4.6.1:
  * launchable tags were added to the flatpak app metainfo files.
  * The Rebase editor (git-cola-sequence-editor) can now add
    "remarks" to commits. Remarks are simple numbered flags (0-9)
    that allow you to mark commits. This lets you visually
    highlight commits to aid you when rebasing and grouping
    related commits across a large patch series. Remarks can be
    added to a single commit or to all commits that touch a file.
    (#1375)
  * Invalid commit.template configuration is now reported in the
    Console tool instead of presenting an error traceback dialog
    via a UsageError exception.
  * The file system monitor was corrected to catch
    PermissionError exceptions. (bz #2260155)
  * If the polib module (e.g. sudo apt install python3-polib) is
    installed then it will be used instead of the vendored
    cola.polib module. This makes it easier for distributions to
    remove the vendored module from the cola namespace. polib is
    now listed as an install requirement in pyproject.toml. (bz
    [#2264526])
  * The flatpak metainfo now contains the required developer name
    field.
  * The "actions/cache" and "styfle/cancel-workflow-action"
    github actions were upgraded.
  * The test suite now uses ruff to validate python code. pylint
    is no longer used. (#1353)
* Sat Jan 27 2024 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.5.0
- Usability, bells and whistles
  * "Stage Modified" was added to the available toolbar actions.
    https://github.com/git-cola/git-cola/issues/1371
  * "Stage Untracked" no longer stages modified files when the list of
    untracked files to stage is empty.
    https://github.com/git-cola/git-cola/issues/1371
  * `Ctrl + Space` can now be used to display the autocomplete options in input fields
    that provide autocompletion.
  * The Diff widget now displays the currently selected filename.
    Uncheck the "Show filenames" option in the Diff widget's tool menu
    to disable this feature.
    https://github.com/git-cola/git-cola/issues/1367
  * The "Fetch", "Push" and "Pull" dialogs now have an embedded progress bar instead
    of displaying a progress bar in a separate popup window.
  * The "Fetch", "Push" and "Pull" dialogs will now stay open after the remote
    operation completes when the "Close on completion" checkbox is unchecked.
    These dialogs closed themselves unconditionally before this change.
- Fixes
  * PyQt6 compatibility for the "Find in diff" feature.
  * PyQt6 compatibility for the ``git dag`` Gravatar icons.
- Translations
  * Updated Polish translation.
    https://github.com/git-cola/git-cola/pull/1368
- Packaging and Dependencies
  * The vendored `qtpy` library was updated to `v2.4.1`.
  * The documentation no longer depends on `jaraco.packaging`.
- Development
  * upload-artifact and setup-python github actions were upgraded.
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 4.4.1:
  * Usability, bells and whistles
  * The remote messages dialog is now displayed for the Pull and
    Push actions in the
  * Branches widget only. This dialog is disabled by default and
    enabled in the
  * main Push and Pull dialog settings.
  * The whole-file staging actions in the Diff widget's right-
    click menu are now listed
  * after the selection and hunk staging actions. This helps
    prevent accidental clicks
  * from clobbering the index for the entire file.
  * The completion popup no longer reappears after an item is
    selected in the
  * "Checkout Branch" action and similar dialogs.
  * Fixes
  * PyQt6 compatibility was improved.
- switch to PyQt6
* Sat Nov 18 2023 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Git Cola now preserves `# commentary` in commit messages by
    default.
  * `git dag` now includes completions for `git log` options in
    the text input field.
  * `git dag` now provides convenient search filters when right-
    clicking in the text input field.
  * A `1.25 x` Hi-DPI magnification option mode is now available
    in the Appearance settings.
  * Git Cola now runs `git commit` in the background and feedback
    is provided while the commit is running. This prevents the
    UI from freezing when running pre-commit hooks that can make
    `git commit` take a long time to run.
  * The Diff context menu was reworked to reduce visual clutter
    and better match the Status context menu.
  * The standalone `git cola tag` tool now autocompletes the tag
    name field.
  * The "Branches" dock widget now has a "Visualize" right-click
    menu option.
  * The "Stash" dialog learned to rename stashes.
  * The "Fetch", "Push" and "Pull" dialogs can now display remote
    messages from the server.
  * `git dag` fixed how it was handling refspec arguments.
  * `git dag` will now properly refresh itself when remote
    branches are updated.
  * Git Cola's python code style. We were previously disabling
    quote normalization when using `black`. Use of `cercis`
    allows us to enable quote normalization under its default
    single-quote settings.
  * Compatibility with Sphinx 7.2.0 was added to the
    `sphinxtogithub` sphinx documentation plugin.
* Sat Sep  2 2023 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.3.2
- Usability, bells and whistles
  * The minimum font size can now be set lower, which is helpful for Hi-DPI displays.
    https://github.com/git-cola/git-cola/pull/1342
- Fixes
  * `git dag` was not displaying history when refspecs were specified.
    https://github.com/git-cola/git-cola/issues/1334
- Development
  * Compatibility with Sphinx 7.2.0 was added to the `sphinxtogithub`
    sphinx documentation plugin.
    https://github.com/git-cola/git-cola/pull/1336
* Tue Aug 22 2023 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.3.1
- Fixes
  * The pypi wheel was fixed to include entry_points.txt.
  * The "Revert" command was throwing an exception after succesfully completing.
* Sun Aug 13 2023 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.3.0
- Usability, bells and whistles
  * `git dag` now displays commit metadata more similarly to `git log`.
    The commit date is now displayed and the subject field is displayed
    directly above the extended description.
  * `git dag` now supports a `cola.logdate` configuration for controlling
    the date format. The configured value is passed to `git log --date=<format>`.
    https://github.com/git-cola/git-cola/pull/1319
    https://github.com/git-cola/git-cola/issues/1312
  * The default `patches` directory that is used when exporting patches
    is now configurable using the `cola.patchesdirectory` configuration
    variable and the Preferences dialog.
  * The Diff Editor can now export the diff selection, or the current
    diff hunk, to a `*.patch` file from the `Patches` context menu action.
  * Existing patches can be appended to by choosing a patch file from
    the `Append Patch` sub-menu in the `Patches` context menu action.
  * Patches can now be applied by dragging and dropping patches files from
    a file browser onto the diff editor. The "Apply Patches" dialog is
    launched with the drag-and-dropped patch files.
  * Shell completions for zsh are now provided in the source distribution.
    See the `contrib/_git-cola` zsh completion file for more details
- Fixes
  * ``QApplication::desktop()`` is no longer available on PyQt6.
    Git Cola no longer relies on this method.
- Packaging
  * Git Cola can now be installed on Windows using `winget`.
    See the ``README.md`` file for more details.
    https://github.com/git-cola/git-cola/pull/1318
* Mon Apr  3 2023 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.2.1
- Fixes
  * Diffs for repositories with a single commit have been fixed.
  https://github.com/git-cola/git-cola/issues/1306
  * The toolbars follow the Qt toolbar style, as they did prior to `v4.2.0`.
  https://github.com/git-cola/git-cola/issues/1307
  * The "Checkout Branch" dialog was fixed to display all completions when first shown.
  https://github.com/git-cola/git-cola/issues/1308
* Mon Mar 27 2023 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.2.0
- Usability, bells and whistles
  * The Diff Editor can now send diffs to your favorite editor before the diffs are applied.
  The right-click "Edit Diff ..." menu actions and the `Ctrl + Shift + S` /
  `Ctrl + Shift + U` hotkeys send the current diff hunk, or the selected diff, to your
  editor before they are applied to the worktree / staging area.
  https://github.com/git-cola/git-cola/pull/1290
  https://github.com/git-cola/git-cola/issues/794
  * The Diff Editor and DAG viewer can now search within their diffs using
  `Ctrl + F` and `Ctrl + G` hotkeys.
  https://github.com/git-cola/git-cola/issues/1116
  * A new *Diff Mode* can be used to diff and unstage edits relative to any commit.
  https://github.com/git-cola/git-cola/issues/816
  * The Commit Message Editor can now spell-check the summary field. Previously only the
  "Extended Description..." field supported spell checking.
  https://github.com/git-cola/git-cola/issues/633
  https://github.com/git-cola/git-cola/issues/1070
  * Repositories in your "Recents" and "Favorites" can now be searched using the new
  "Search" tool button. Quickly switch between these repositories using the `Alt + P`
  hotkey and "Quick Open..." File menu action.
  https://github.com/git-cola/git-cola/pull/1282
  * "Favorites", "Recents" and the startup dialog now display a case-insensitively
  sorted list of repositories.
  https://github.com/git-cola/git-cola/issues/1047
  * The startup dialog now has a right-click context menu that allows you to prune
  stale entries and other actions that were not previously accessible from
  the startup dialog.
  https://github.com/git-cola/git-cola/issues/1199
  https://github.com/git-cola/git-cola/pull/1280
  * The "Copy Leading Paths" action in the Status tool's right-click "Copy" sub-menu
  can now strip off an arbitrary number of leading paths.
  https://github.com/git-cola/git-cola/issues/784
  * The "Cherry-Pick" action now reports errors when "git cherry-pick" fails.
  A new "Abort Cherry-Pick" action has been added for aborting a failed cherry-pick.
  https://github.com/git-cola/git-cola/issues/1062
  * The diff text can now be quickly zoomed using `Ctrl + Mouse wheel` scroll.
  This will quickly change the text size within the current session only.
  https://github.com/git-cola/git-cola/issues/1029
  * The Console and Diff widgets learned to open URLs. Right-click on a line
  that contains http URLs and context-menu actions for opening each URL
  using your default web browser will be displayed.
  https://github.com/git-cola/git-cola/issues/1139
  * Drag-and-drop has been improved when dragging filenames from the Status tool.
  Dragging multiple files requires special handling to improve usability.
  Some terminals (such as `kitty`) consume multiple file URLs by separating paths with
  newlines. This is useful when you'd like to capture raw filenames but is less
  convenient when dropping  filenames onto a command-line. Drag with the `Alt`-modifier
  held down to drag-and-drop filenames for command-line use. Using the `Alt` modifier
  omits URLs so that the drag-and-drop payload includes only space-delimited,
  shell-quoted paths.
  https://github.com/git-cola/git-cola/issues/719
  * The DAG viewer now displays the diff between the start and end commits when
  multiple commits are selected. The diffs are displayed in the DAG's diff viewer.
  https://github.com/git-cola/git-cola/issues/552
  * The DAG viewer learned to checkout branches and initiate rebases from its right-click menu.
  https://github.com/git-cola/git-cola/issues/1113
  * The DAG diff viewer learned to word-wrap the diff text.
  https://github.com/git-cola/git-cola/issues/1242
  * The spelling dictionaries are now discovered dynamically at runtime.
  `dict/words` and `dict/propernames` are now discovered via `$XDG_DATA_DIRS`
  by the spell checker. This allows a spelling dictionary to be placed in eg.
  `~/.local/share/dict/words` to override the default `/usr/share/dict/words`.
  https://github.com/git-cola/git-cola/issues/873
  * The File menu now has a "Patches" sub-menu with a full set of "git am" Patch actions.
  * The Diff Editor and various Diff widgets now have a "Copy Diff" action with an
  `Alt + Shift + C` hotkey that copies the selected diff text to the clipboard with the
  `+`, `-` and `<Space>` diff prefix characters removed.
  https://github.com/git-cola/git-cola/issues/1288
  * The "Revert" action for reverting commits from the DAG tool now displays error
  messages when ``git revert`` fails.
  https://github.com/git-cola/git-cola/issues/885
  * The Diff Editor now uses an easier-to-see *block cursor* by default.
  Disable `cola.blockcursor <https://git-cola.readthedocs.io/en/latest/git-cola.html#cola-blockcursor>`_
  to continue using original *line cursor* by running
  ``git config --global cola.blockcursor false``, or by editing the settings in the menu.
  * The "Unmerged" header item in the Status tool now displays a summary list of unmerged files.
  * The hotkeys documentation has been updated to clarify that the "Copy Commit ID"
  action is available in several tools.
  https://github.com/git-cola/git-cola/issues/779
  * Saving files when using "Browse Other Branch" now displays errors from
  ``git show`` when saving files from arbitrary commits.
  https://github.com/git-cola/git-cola/issues/1065
  * The Apply Patches dialog now reports errors when patches fail to apply.
  https://github.com/git-cola/git-cola/issues/673
  * The "Status" tool now disables "Copy" actions in its context menu when no
  files have been selected.
  https://github.com/git-cola/git-cola/issues/697
  * The "Unstage" menu item in the Status tool now uses a "Remove" icon.
  https://github.com/git-cola/git-cola/pull/1289
- Development
  * The vendored `qtpy` module was modified to sever its dependency on the
  `packaging.version` module. This mostly affects users that want to run
  Git Cola directly from the the source tree outside of any virtualenv.
  https://github.com/git-cola/git-cola/issues/1286
* Wed Feb 15 2023 Илья Индиго <ilya@ilya.cf>
- Added python3-qt5 to requires.
* Tue Dec 27 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.1.0
- Usability, bells and whistles
  * The rebase editor was taught to handle stacked branch workflows enabled by
  ``git rebase --update-refs``. The `git cola rebase` sub-command now has
  an `--update-refs` option and the menu actions display a prompt that allows
  you to enable the updating of stacked branches.
  https://github.com/git-cola/git-cola/pull/1261
  https://github.com/git-cola/git-cola/issues/571
  * The status widget now respects `diff.ignoreSubmodules`.
  https://github.com/git-cola/git-cola/issues/1269
- Packaging and Dependencies
  * PyQt6 is now officially supported.
  https://github.com/git-cola/git-cola/issues/1211
  https://github.com/git-cola/git-cola/issues/1273
  * The vendored `qtpy` library was updated to `v2.3.0`.
- Development
  * Fixes and updates to Git Cola's CI actions.
  https://github.com/git-cola/git-cola/pull/1278
  https://github.com/git-cola/git-cola/issues/1277
* Thu Nov 24 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.0.4
- Fixes
  * The "T" hotkey for "Find Files" was removed to avoid issues in some configurations.
  https://github.com/git-cola/git-cola/issues/1270
  * Some context menus entries were erroring out on binary files.
  https://github.com/git-cola/git-cola/pull/1271
* Fri Nov 11 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.0.3
- Usability, bells and whistles
  * The branches widget no longer loses its selection state in response to
  notifications and UI actions.
  https://github.com/git-cola/git-cola/issues/1221
  * The use of ``gravatar.com`` to fetch icons associated with author emails
  can now be disabled by setting `git config --global cola.gravatar false`.
  https://github.com/git-cola/git-cola/issues/933
- Fixes
  * The config reader has been revamped to better read settings when git config
  files are located in unexpected locations.
  https://github.com/git-cola/git-cola/issues/927
  https://github.com/git-cola/git-cola/issues/1264
  * The preferences dialog no longer throws an error when the editor has not
  been configured.
  https://github.com/git-cola/git-cola/issues/1263
  * Context menu actions for staging files has been added when diffing images.
  https://github.com/git-cola/git-cola/issues/1265
  * The stash editor now properly displays stashes with slashes ("/") in
  their names or messsages.
  https://github.com/git-cola/git-cola/pull/1267
  * The settings file is now written-to and read-from in a robust manner to avoid data
  loss when doing an ACPI shutdown or forced shutdown of a machine.
  https://github.com/git-cola/git-cola/issues/1241
  * Git Cola now displays an error message when attempting to open a repository that
  cannot be accessed due to the new `safe.directory` protections in Git v2.30.3.
  https://github.com/git-cola/git-cola/issues/1243
- Translations
  * The .po and .pot files now contain location information.
  https://github.com/git-cola/git-cola/issues/880
* Thu Sep 29 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.0.2
- Usability, bells and whistles
  * The Rebase editor (`git-cola-sequence-editor`) now supports multi-select.
  Use `Shift-{Up,Down}` to select multiple lines and the keyboard hotkeys
  listed in the `?` dialog to drive the UI.
  https://github.com/git-cola/git-cola/pull/1257
  * The `$GIT_VISUAL` and `$VISUAL` environment variable are now consulted in addition
  to `$GIT_EDITOR` and `$EDITOR` when the `gui.editor` configuration is unset.
  https://github.com/git-cola/git-cola/pull/1237
  * The application window icon is now enabled when running on Wayland.
  https://github.com/git-cola/git-cola/pull/1240
  * The Status widget now has an "Open Worktree" action.
  https://github.com/git-cola/git-cola/pull/1245
  * The "Open Using Default Application", "Open Directory",
  "Open Parent Directory" and "Open Worktree" actions are now available on Windows.
  * The dialog for opening repositories is now a read-only dialog that omits the
  ability to create folders and modify the filesystem.
  https://github.com/git-cola/git-cola/issues/1168
  * A few more `git` calls have been eliminated from the startup sequence.
  This further improved the startup time for Git Cola.
  https://github.com/git-cola/git-cola/pull/1259
- Fixes
  * Documentation rendering errors have been fixed.
  https://github.com/git-cola/git-cola/pull/1256
  * Use of a `~/.config/git-cola/language` file to override the language has been fixed.
  https://github.com/git-cola/git-cola/issues/1246
  * We no longer write the `cola.spellcheck` configuration value on launch.
  https://github.com/git-cola/git-cola/pull/1238
- Translations
  * Updated Spanish translation.
  https://github.com/git-cola/git-cola/pull/1244
  * Updated Japanese translation.
  https://github.com/git-cola/git-cola/pull/1249
- Packaging
  * Building documentation offline is supported again.
  https://github.com/git-cola/git-cola/issues/1250
  * The Appstream Metadata files were missing in the v4.0.0 release are included again.
  https://github.com/git-cola/git-cola/pull/1254
  https://github.com/git-cola/git-cola/issues/1253
* Sat Jun 11 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.0.1
- Usability, bells and whistles
  * Double-clicking dock widgets no longer creates sub-windows when the layout is locked.
  https://github.com/git-cola/git-cola/issues/1176
  https://github.com/git-cola/git-cola/pull/1198
- Fixes
  * We now guard against `locale.getdefaultlocale()` returning `None` in some
  configurations, notably on macOS if none of 'LC_ALL', 'LC_CTYPE', 'LANG' or 'LANGUAGE'
  are defined.
  https://github.com/git-cola/git-cola/issues/1234
  * The preferences dialog has been fixed to properly handle booleans.
  https://github.com/git-cola/git-cola/issues/1235
  * The `docs/` directory was restructured to avoid missing `setup.py` errors.
  `share/doc/git-cola` is now a symlink pointing to `docs/`.
  https://github.com/git-cola/git-cola/issues/1230
  * Message boxes could sometimes display off-screen or using geometry that is larger
  than the current desktop. Message box sizes are now clamped to the desktop size.
  https://github.com/git-cola/git-cola/issues/1228
* Sat May 28 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 4.0.0
- These changes are primarily breaking changes for packagers of Git Cola.
  For example, Linux distribution and Homebrew package maintainers may need to
  be aware of these changes.
  Changes have been made build infrastructure and the resulting filesystem artifacts.
  * The build system is now Python3-only and has been modernized for PEP-517/518.
  While Git Cola still builds and runs under Python2, it is no longer officially
  supported and may stop working in a future release without notice.
  https://github.com/git-cola/git-cola/issues/1201
  * The `#!/usr/bin/env python` shebang lines in the `git-cola` and `git-dag` wrapper
  scripts have been updated to use `python3`.
  https://github.com/git-cola/git-cola/pull/1204
  * The build system was switched to `setuptools` and no longer depends on `distutils`.
  ``python setup.py {build,install,build_pot,build_mo}`` are no longer provided.
  Use the https://pypa-build.readthedocs.io/en/stable/installation.html
  ``python -m build`` tool to generate sdist and wheel distributions,
  and ``pip install .`` to install Git Cola from source.
  https://github.com/git-cola/git-cola/pull/1204
  * The `git-cola`, `git-dag` and `git-cola-sequence-editor` commands are now installed
  using setuptools entry points.
  * The `bin/` wrapper scripts in the source tree continue to be provided for convenience
  but they are not the scripts that get installed.
  * The `qtpy` Python package is no longer installed alongside the `cola` Python package.
  * The `cola` package is now installed into the standard Python site-packages location.
  * The `share/git-cola/lib` private Python modules directory no longer exists.
  * The `NO_VENDOR_LIBS` and `NO_PRIVATE_LIBS` Makefile options are no longer necessary.
  * The `share/git-cola` filesystem namespace no longer exists. All of cola's package data
  is distributed alongside the `cola` module as package data.
  * Building the Sphinx documentation now also requires the `jaraco.packaging` and
  `rst.linker` packages. See `requirements/requirements-dev.txt` for the package
  requirement details.
- Usability, bells and whistles
  * Custom UI themes
  https://git-cola.readthedocs.io/en/latest/git-cola.html#custom-themes
  can be used by adding `*.qss` Qt stylesheet files to `~/.config/git-cola/themes/`.
  https://github.com/git-cola/git-cola/pull/1222
  https://github.com/git-cola/git-cola/pull/1226
  * Git Cola now keeps track of child Browser windows and will close all of them when
  the main window is closed.
  https://github.com/git-cola/git-cola/pull/1200
- Fixes
  * Staging conflicted binary files has been fixed to avoid Unicode decoding errors.
  https://github.com/git-cola/git-cola/issues/1189
  * Ensure that secure permissions are used when creating temporary files.
  https://github.com/git-cola/git-cola/pull/1209
  * The line numbering in the diff viewer was corrected when displaying merge diffs.
  https://github.com/git-cola/git-cola/pull/1208
  * Documentation typofixes.
  https://github.com/git-cola/git-cola/pull/1193
  * Git Cola was revamped to use Qt signals and slots for all of its notifications.
  This made its notification system more robust.
  https://github.com/git-cola/git-cola/pull/1202
  https://github.com/git-cola/git-cola/pull/1203
  https://github.com/git-cola/git-cola/pull/1205
  https://github.com/git-cola/git-cola/pull/1206
- Packaging
  * `vcruntime140.dll` and `msvcp140.dll` are now included in the Windows installation.
  https://github.com/git-cola/git-cola/pull/1207
* Thu Jan 20 2022 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.12.0
- Usability, bells and whistles
  * The git config guitool action can now be grouped under user-defined menus.
  This is done by using slash (``/``) delimiters in the action name.
  Entries before the final slash are treated like submenus inside the
  top-level ``Actions`` menu.
  https://github.com/git-cola/git-cola/issues/1150
  * Toolbars now have a full set of icons. The icons follow the system theme
  and can be configured to display text, just icons, or text and icons.
  https://github.com/git-cola/git-cola/pull/1171
  * The startup dialog will now open the selected repository when the "enter"
  key is pressed.
  https://github.com/git-cola/git-cola/issues/1162
  * ``S`` is stages selected lines (in addition to ``s``).
  https://github.com/git-cola/git-cola/issues/1187
- Fixes
  * The vendored qtpy library was patched to retain Python2 compatibility.
  * The "Unstage" toolbar action was fixed.
  https://github.com/git-cola/git-cola/issues/1178
  * We now avoid `setWidth(float)` for compatibility with newer Qt versions.
  https://github.com/git-cola/git-cola/pull/1183
  * Documentation typofixes.
  https://github.com/git-cola/git-cola/pull/1185
- Translations
  * Updated Polish translation.
  https://github.com/git-cola/git-cola/pull/1184
- Development
  * Git Cola now uses Github Actions for running its continuous integration tests.
  https://github.com/git-cola/git-cola/pull/1179
* Wed Oct 20 2021 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.11.0
- Usability, bells and whistles
  * The Status tool was improved to better retain selected files when
  the state changes and the display is refreshed.
  https://github.com/git-cola/git-cola/issues/1130
  https://github.com/git-cola/git-cola/pull/1131
  * The Diff editor can now stage selected lines for untracked files.
  Git Cola will detect when a file is untracked and will allow you to
  partially stage it, just like existing tracked files.
  https://github.com/git-cola/git-cola/pull/1146
  https://github.com/git-cola/git-cola/issues/1084
  * Diffing of staged files has been implemented for repositories that contain
  no commits.
  https://github.com/git-cola/git-cola/pull/1149
  https://github.com/git-cola/git-cola/issues/1110
  * Documentation improvements and typofixes.
  https://github.com/git-cola/git-cola/pull/1163
  https://github.com/git-cola/git-cola/pull/1164
- Security
  * The `FIPS security mode` -
  https://developer.mozilla.org/en-US/docs/Mozilla/Projects/NSS/FIPS_Mode_-_an_explanation
  is now supported by Git Cola when running on FIPS-enabled Python
  (Python 3.9+ or centos8/rhel8's patched Python 3.6).
  https://github.com/git-cola/git-cola/issues/1157
- Fixes
  * The `argparse` usage was adjusted to remain compatible with older Pythons.
  https://github.com/git-cola/git-cola/issues/1155
  * The window restoration logic was fixed to properly save/restore settings
  when different languages are used.
  https://github.com/git-cola/git-cola/issues/1071
  https://github.com/git-cola/git-cola/issues/1161
  https://github.com/git-cola/git-cola/issues/382
  * `git dag` no longer passes floats to `QPen::setWidth()` for better compatibility.
  https://bugzilla.redhat.com/show_bug.cgi?id=2014950
- Packaging
  * The Windows installer was slimmed down by removing unused Qt DLLs.
  https://github.com/git-cola/git-cola/pull/1152
* Thu Jul 15 2021 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.10.1
- Patch release to fix a typo in the Interactive Rebase feature.
* Thu Jul 15 2021 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.10
- Usability, bells and whistles
  * The git config reader now supports the `include.path` directive
  for including config files.
  https://github.com/git-cola/git-cola/issues/1136
  https://github.com/git-cola/git-cola/pull/1137
  * The dialog for selecting commits now support filtering.
  https://github.com/git-cola/git-cola/pull/1121
  * The diff editor now wraps long lines by default. The diff options
  menu can be used to enable/disable line wrapping.
  https://github.com/git-cola/git-cola/pull/1123
  * Git Cola now honors `core.hooksPath` for configuring custom Git hooks,
  which was introduced in Git v2.9.
  https://github.com/git-cola/git-cola/issues/1118
  * A new `Ctrl + Shift + S` hotkey was added for staging/unstaging all
  files, both modified and untracked.
  * The `Status` tool now supports `Ctrl + A` for selecting all files and
  it behaves more predictably when performing operations when multiple
  categories of files are selected (eg. when both modified and untracked
  header items are selected).
  https://github.com/git-cola/git-cola/issues/1117
- Translations
  * Updated Hungarian translation.
  https://github.com/git-cola/git-cola/pull/1135
- Fixes
  * The "Interactive Rebase" feature was updated to work with Windows.
  * `make install-man` was updated to support Sphinx 4.0.
  https://github.com/git-cola/git-cola/issues/1141
  * `git cola --help-commands` was updated for newer versions of argparse.
  https://github.com/git-cola/git-cola/issues/1133
- Development
  * Git Cola can now be started as a Python module.
  https://github.com/git-cola/git-cola/pull/1119
* Fri Feb 19 2021 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.9
- Usability, bells and whistles
  * The startup dialog now detects when Recent and Favorite repositories no
  longer exist on disk, and offers to remove these entries when selected.
  https://github.com/git-cola/git-cola/pull/1089
  * The startup dialog now includes a simpler and more condensed folder view
  that can be used for selecting Favorites and Recent repositories.
  https://github.com/git-cola/git-cola/pull/1086
  * The "Commit" menu now includes an "Undo Last Commit" action.
  https://github.com/git-cola/git-cola/issues/890
  * The "Reset" menu was revamped to expose all of Git's reset modes alongside a
  new "Restore Worktree" action that updates the worktree using "git read-tree".
  https://github.com/git-cola/git-cola/issues/890
- Translations
  * Updated Polish translation.
  https://github.com/git-cola/git-cola/pull/1107
  * Updated Japanese translation.
  https://github.com/git-cola/git-cola/pull/1098
  * Updated Brazilian translation.
  https://github.com/git-cola/git-cola/pull/1091
- Packaging
  * The ``--use-env-python`` option for ``setup.py`` is now Python3 compatible.
  https://github.com/git-cola/git-cola/issues/1102
* Tue Nov 10 2020 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.8
- Usability, bells and whistles
  * The submodules widget can now be used to add submodules.
  Submodules are now updated recursively.
  https://github.com/git-cola/git-cola/issues/534
  * The image diff viewer can now be toggled between text and image modes.
  This is helpful when, for example, diffing .svg files where it can be useful
  to see diffs in both an image and text representation.
  https://github.com/git-cola/git-cola/issues/859
  https://github.com/git-cola/git-cola/pull/1035
  * The default `ssh-askpass` username + password dialog included with Git Cola
  can now toggle between showing and masking the password input field.
  https://github.com/git-cola/git-cola/pull/1069
- Translations
  * Updated Polish translation.
  https://github.com/git-cola/git-cola/pull/1076
  * Updated Hungarian translation.
  https://github.com/git-cola/git-cola/pull/1067
- Packaging
  * The `share/appdata` AppStream data was renamed to `share/metainfo`
  in accordance with `AppStream standard changes from 2016
  https://github.com/ximion/appstream/blob/master/NEWS#L1363
  https://github.com/git-cola/git-cola/pull/1079
  * The "cola" modules are now installed into the Python "site-packages"
  directory by default.  This allows distributions to package "git-cola" for
  multiple versions of Python.  See the PACKAGING NOTES section in the README
  for details about suppressing the installation of the private
  "share/git-cola/lib/cola" modules when building cola.
  https://github.com/git-cola/git-cola/issues/181
  * Git Cola's rebase / sequence editor, formerly known as "git-xbase" and
  installed as "share/git-cola/bin/git-xbase", has been renamed to
  "git-cola-sequence-editor" and is now installed into the default
  "bin/git-cola-sequence-editor" executable location to enable external
  reuse of this general-purpose tool.
  * A workaround used by the pynsist installer preamble script was obsoleted by
  https://github.com/takluyver/pynsist/pull/149
  and has now been removed.
  https://github.com/git-cola/git-cola/pull/1073
- Fixes
  * `git dag` now uses integer widths when initializing its brushes.
  https://github.com/git-cola/git-cola/pull/1080
* Sun May 24 2020 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.7
- Usability, bells and whistles
  * The `git-xbase` rebase editor now includes a file list for filtering
  the changes displayed in the diff view.
  https://github.com/git-cola/git-cola/pull/1051
  * The fallback `ssh-askpass` script, which provides the Username/Password
  login dialog when performing remote operations, previously presented both
  the username and password input fields with `***` asterisks.
  The dialog now uses asterisks for the password field only.
  https://github.com/git-cola/git-cola/pull/1026
  * Stashes can now be applied using the `Ctrl + Enter` hotkey, popped with the
  `Ctrl + Backspace` hotkey, and dropped with the `Ctrl + Shift + Backspace`
  hotkey when inside the stash dialog.  This enables a keyboard-centric
  mouse-free workflow when using the stash dialog.
  * When amending a commit, `git cola` will check whether the commit has been
  published to a remote branch using `git branch -r --contains HEAD`.
  This command can be slow when operating on a repository with many
  remote branches.  The new `cola.checkpublishedcommits` configuration
  variable allows you to opt-out of this check, which improves performance
  when amending a commit.  The settings widget exposes this variable as,
  "Check Published Commits when Amending".
  https://github.com/git-cola/git-cola/issues/1021
  https://github.com/git-cola/git-cola/pull/1027
- Translations
  * Updated Polish translation.
  https://github.com/git-cola/git-cola/pull/1033
- Fixes
  * `git-dag.appdata.xml` was updated to allow network access for author icons.
  https://github.com/git-cola/git-cola/pull/1050
  * The inotify filesystem monitor now handles
  `OSError: [Errno 24] Too many open files` errors by disabling inotify.
  https://github.com/git-cola/git-cola/issues/1015
  * Typos in various documentation files have been fixed.
  https://github.com/git-cola/git-cola/pull/1025
  * The "Recent Repositories" limit was off by one, and now correctly
  remembers the configured number of repositories in the menu.
  https://github.com/git-cola/git-cola/pull/1024
  * The "revert" action in the DAG and other tools now uses
  `git revert --no-edit`, which avoids launching an editor
  when reverting the commit.  Use `Ctrl+m` in the commit message
  editor after reverting a commit to rewrite its commit message.
  https://github.com/git-cola/git-cola/issues/1020
* Mon Dec 23 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Added inotify.patch
  The inotify filesystem monitor now handles
  `OSError: [Errno 24] Too many open files` errors by disabling inotify.
  https://github.com/git-cola/git-cola/issues/1015
  https://bugzilla.opensuse.org/show_bug.cgi?id=1155700
* Wed Nov 27 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.6
- Usability, bells and whistles
  * The remote editor is much faster since it no longer queries
  remotes, and uses the cached information instead.
  https://github.com/git-cola/git-cola/issues/986
  * Commit message templates can now be loaded automatically by setting
  ``git config cola.autoloadcommittemplate true``.
  https://github.com/git-cola/git-cola/pull/1013
  https://github.com/git-cola/git-cola/pull/735
  * The UI layout can now be reset back to its initial state by selecting
  the "Reset Layout" action.  This reverts the layout to the same state
  as when the app first launched.
  https://github.com/git-cola/git-cola/pull/1008
  https://github.com/git-cola/git-cola/issues/994
  * Files can now be ignored in either the project's `.gitignore`, or in the
  repository's private local `.git/info/exclude` ignore file.
  https://github.com/git-cola/git-cola/pull/1006
  https://github.com/git-cola/git-cola/issues/1000
  * New remotes are now selected when they are added in the "Edit Remotes" tool.
  https://github.com/git-cola/git-cola/pull/1002
  * The "Recent" repositories list is now saved to disk when opening a
  repository.  Previously, this list was only updated when exiting the app.
  https://github.com/git-cola/git-cola/pull/1001
  * The bookmarks tool now has a "Delete" option in its right-click menu.
  https://github.com/git-cola/git-cola/pull/999
  * The current repository is no longer listed in the "File/Open Recent" menu.
  https://github.com/git-cola/git-cola/pull/998
- Translations
  * Updated Hungarian translation.
  https://github.com/git-cola/git-cola/pull/1005
  https://github.com/git-cola/git-cola/pull/1018
  * Updated Turkish translation.
  https://github.com/git-cola/git-cola/pull/1003
  https://github.com/git-cola/git-cola/pull/1011
- Fixes
  * Better support for Python 3.8's line buffering modes.
  https://github.com/git-cola/git-cola/pull/1014
  * The default `ssh-askpass` script now uses a more generic `#!` shebang line.
  https://github.com/git-cola/git-cola/pull/1012
  * Fetch, push, and pull operations will now refresh the model and display when
  operations complete.
  https://github.com/git-cola/git-cola/issues/996
  * The branches widget now refreshes its display when changing branches.
  https://github.com/git-cola/git-cola/pull/992
- Packaging
  * The `share/git-cola/bin/git-xbase` script will now have its `#!` lines
  updated during installation.
  https://github.com/git-cola/git-cola/pull/991
- Development
  * The unit tests were made more platform-independent.
  https://github.com/git-cola/git-cola/pull/993
* Mon Sep 23 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Force to use python3
* Mon Sep 23 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.5
- Usability, bells and whistles
  * Auto-completion for filenames can now be disabled.  This speeds up
  revision completion when working in large repositories with many files.
  https://github.com/git-cola/git-cola/pull/981
  * The Stash dialog now shows the stash date as a tooltip when hovering
  over a stashed change.
  https://github.com/git-cola/git-cola/pull/982>
  * Qt HiDPI settings are overriden by the `git cola` HiDPI appearance settings.
  These overrides can now be disabled by selecting the "Disable" mode.
  This allows users to control Qt's HiDPI settings through environment
  variables.  Additionally, the "Auto" mode now detects the presence of
  the Qt HiDPI variables and no longer overrides them when the user has
  configured their environment explicitly.
  https://github.com/git-cola/git-cola/issues/963
  * Confirmation dialogs can now focus buttons using the Tab key.
  Previously, the "Y" and "N" keys could be used to confirm or deny
  using the keyboard, but "Tab" is more familiar.
  https://github.com/git-cola/git-cola/issues/965
  * Error dialogs (for example, when a commit hook fails) will now always
  show the details.  The details were previously hidden behind a toggle.
  https://github.com/git-cola/git-cola/issues/968
- Translations
  * Updated Japanese translation.
  https://github.com/git-cola/git-cola/pull/973
  https://github.com/git-cola/git-cola/pull/974
  * Updated Simplified Chinese translation.
  https://github.com/git-cola/git-cola/pull/950
- Fixes
  * The filesystem monitor no longer logs that it has been enabled after the
  inotify watch limit is reached on Linux.
  https://github.com/git-cola/git-cola/pull/984
  * Better unicode robustness.
  https://github.com/git-cola/git-cola/issues/990
  https://github.com/git-cola/git-cola/issues/991
  * The "Branches" widget did not always update itself when deleting branches
  (for example, when inotify is disabled or unavailable).
  https://github.com/git-cola/git-cola/issues/978
  * Non-ascii unicode byte strings are more robustly handled by the log widget.
  https://github.com/git-cola/git-cola/issues/977
  * Non-unicode results from the `gettext` library are more robustly handled.
  https://github.com/git-cola/git-cola/issues/969
  * Launching `git cola` from within a directory that has since been deleted
  would previously result in a traceback, and is now robustly handled.
  https://github.com/git-cola/git-cola/issues/961
* Tue Jul 23 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Fixed Send2Trash names
* Sun Jul 21 2019 Yunhe Guo <i@guoyunhe.me>
- Python dependencies can be either Python 2 or Python 3
* Mon Jun 17 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.4
- Usability, bells and whistles
  * The file browser now includes "Blame" in its context menu.
  https://github.com/git-cola/git-cola/issues/953
  * The "Push" action now uses "git push --force-with-lease" when using
  the "Force" option with Git v1.8.5 and newer.
  https://github.com/git-cola/git-cola/issues/946
  * Updated German translation.
  https://github.com/git-cola/git-cola/pull/936
  * The `Status` widget learned to optionally display file counts in its
  category headers, and indent the files displayed in each category.
  https://github.com/git-cola/git-cola/pull/931
  * The `Branches` widget can now sort branches by their most recent commit.
  https://github.com/git-cola/git-cola/pull/930
  * `git cola` now includes configurable GUI themes that can be used to style
  the user interface.  Enable the new themes by configuring `cola.theme`
  in the preferences window.  See the
  `cola.theme documentation https://git-cola.readthedocs.io/en/latest/git-cola.html#cola-theme
  for more details.
  https://github.com/git-cola/git-cola/pull/924
  * `git cola` now has built-in support for HiDPI displays by enabling
  Qt's 5.6's `QT_AUTO_SCREEN_SCALE_FACTOR` feature.
  https://github.com/git-cola/git-cola/issues/938
  * `git cola` now uses HiDPI pixmaps when rendering icons, and the builtin
  icons have been updated to look sharp when displayed in HiDPI.
  https://github.com/git-cola/git-cola/pull/932
- Fixes
  * `git cola`'s "Revert Unstaged Edits" previously checked out from "HEAD^",
  when in "Amend" mode, and removing staged changes.  This behavior has been
  changed to always checkout from the index, which avoids data loss.
  https://github.com/git-cola/git-cola/issues/947
  * `git cola` has been updated to work with newer versions of `gnome-terminal`
  and no longer shell-quotes its arguments when launching `gnome-terminal`.
  The `cola.terminalshellquote` configuration variable can be set to `true` to
  get the old behavior, or to handle other terminals that take the command to run
  as a single string instead of as arguments to `execv()`.
  https://github.com/git-cola/git-cola/pull/935
  * `git dag` now properly handles arbitrary input on Python3.
  Previously, an exception would be raised when entering `--grep=xxx` where
  `xxx` is a quoted string with a missing end-quote.
  https://github.com/git-cola/git-cola/pull/941
- Development
  * The contribution guidelines for contributors has been updated to mention
  how to regenerate the `*.mo` message files.
  https://github.com/git-cola/git-cola/pull/934
* Fri Feb  8 2019 Marcin Bajor <marcin.bajor@gmail.com>
- Update to 3.3
- Usability, bells and whistles
  * git dag improved how it renders parent commits. (#921)
  * The Branches widget now checks out branches when double-clicked. (#920)
  * The new Submodules widget makes it easy to interact with submodules.
  Additionally, submodules can now be updated using the Status widget. (#916)
  * Updated Japanese translation. (#914)
  * The “Open Terminal” action now launches a Git Bash shell on Windows. (#913)
  * New menu actions for updating all submodules. (#911)
  * The status widget can now update submodules. (#911)
  * The “Apply Patch” git cola am dialog now includes a diff viewer to display
  the contents of the selected patch.
  * The “Alt+D” diffstat hotkey now selects the staged/modified/etc. header in
  the Status widget, which shows the totality of everything that will be committed. (#771)
  * Running “Launch Editor” from the diff editor now opens the editor at the current line. (#898)
  * The textwidth and tabwidth configuration values can now be set per-repository,
  rather than globally only.
  * Text entry widgets switched to using a block cursor in v3.2.
  This has been reverted to the original line cursor for consistency with other
  applications and user expectations. (#889)
  * The “edit at line” feature, used by the “Grep” tool, now supports the Sublime text editor. (#894)
- Fixes
  * Launching external programs has been improved on Windows. (#925)
  * Improve compatibility when using PySide2. (#912)
  * The Diff Editor was not honoring the configured tab width on startup. (#900)
  * The “Delete Files” feature was creating an unreadable display when many files were selected.
  Word-wrap the list of files so that the display stays within a sensible size. (#895)
  * Spelling and grammar fixes. (#915) (#891)
- Development
  * The logo was run through tidy to give it a consistent style.
  Some technical issues with the logo were improved. (#877)
  * The entire codebase is now checked by flake8, rather than just the module and test directories.
  This catches things like the pynsist installer scripts. (#884) (#882) (#879)
- Packaging
  * The vendored qtpy library was updated to v1.6.
  * The Windows installer’s wrapper scripts were missing an import. (#878)
* Sat Oct 20 2018 Jacob W <jacob@jacobwinski.com>
- Change to use QT5 instead of QT4 as recommended by upstream (see README.md).
  * Fixes 100%% CPU usage bug https://github.com/git-cola/git-cola/issues/781
* Sun Aug 26 2018 jengelh@inai.de
- Ensure neutrality of descriptions.
* Sun Aug 26 2018 marcin.bajor@gmail.com
- Update to 3.2
- Usability, bells and whistles
  * The `git cola dag` DAG window now supports `git revert`.
  https://github.com/git-cola/git-cola/issues/843
  * `git stash pop` is now supported by the stash dialog.
  https://github.com/git-cola/git-cola/issues/844
  * The status widget now ensures that each item is visible when selection
  changes.  Previously, if you scrolled to the right to see the name of
  a long filename, and then selected a short filename above it, the widget
  may not have shown the short filename in the viewport.  We now ensure
  that the filenames are visible when the selection changes.
  https://github.com/git-cola/git-cola/pull/828
  * The `git xbase` rebase editor no longer displays an error when
  cancelling an interactive rebase.
  https://github.com/git-cola/git-cola/issues/814
  * The dialog shown when renaming remotes has been simplified.
  https://github.com/git-cola/git-cola/pull/840
  https://github.com/git-cola/git-cola/issues/838
  * The help dialog in the `git-xbase` Rebase editor is now scrollable.
  https://github.com/git-cola/git-cola/issues/855
- Translations
  * Updated Brazilian translation
  https://github.com/git-cola/git-cola/pull/845
  * Updated Czech translation
  https://github.com/git-cola/git-cola/pull/854
  https://github.com/git-cola/git-cola/pull/853
  https://github.com/git-cola/git-cola/pull/835
  https://github.com/git-cola/git-cola/pull/813
  * Update Spanish translation
  https://github.com/git-cola/git-cola/pull/862
  https://github.com/git-cola/git-cola/pull/867
- Packaging
  * The original `#!/usr/bin/env python` shebang lines can now be
  retained by passing `USE_ENV_PYTHON=1` to `make` when installing.
  https://github.com/git-cola/git-cola/issues/850
  * The Makefile is now resilient to DESTDIR and prefix containing whitespace.
  https://github.com/git-cola/git-cola/pull/858
  * The vendored `qtpy` library was updated to `v1.4.2`.
  * `python3-distutils` is needed to build cola on Debian.
  https://github.com/git-cola/git-cola/issues/837
- Fixes
  * The "C" key no longer closes the message dialogs, for example the
  one that is shown when a commit fails its pre-commit hooks.
  This allows "Ctrl+C" copy to work, rather than closing the dialog.
  https://github.com/git-cola/git-cola/issues/734
  * Dock widgets sizes are now properly saved and restored when the main
  window is maximized.
  https://github.com/git-cola/git-cola/issues/848
  * The spellcheck feature was broken under Python3.
  https://github.com/git-cola/git-cola/issues/857
  * A regression when saving stashes was fixed.
  https://github.com/git-cola/git-cola/issues/847
  * Diffing image files was not updating the available context menus,
  which prevented the "Stage" action from being present in the menu.
  https://github.com/git-cola/git-cola/issues/841
  * `git cola` now detects when `git lfs uninstall` has been run.  This allows
  you to re-initialize "Git LFS" in an existing repository where it had been
  previously uninstalled.
  https://github.com/git-cola/git-cola/issues/842
  * Custom color values that did not contain any hexadecimal digits in the
  `a-f` range were being converted into integers by the config reader.  This
  then caused the configured colors to be ignored.
  These color values are now interpreted correctly.  Additionally, color
  values can now use an optional HTML-like `#` prefix.
  Example `.gitconfig` snippet::
    [cola "color"]
    text = "#0a0303"
  https://github.com/git-cola/git-cola/pull/836
  https://github.com/git-cola/git-cola/issues/849
  * We now display an error message graphically when `Git` is not installed.
  Previously, the message went to stderr only.
  https://github.com/git-cola/git-cola/issues/830
  * Changing diff options was causing resulting in an exception.
  https://github.com/git-cola/git-cola/issues/833
  https://github.com/git-cola/git-cola/pull/834
  * The DAG window now updates itself when branches and tags are created.
  https://github.com/git-cola/git-cola/issues/814
  * The user's `$PATH` environment variable can now contain utf-8
  encoded paths.  Previously, launching external commands could
  lead to tracebacks.
  https://github.com/git-cola/git-cola/issues/807
  * Git Cola development sandboxes can now be stored on utf-8 encoded
  filesystem paths.  Previously, the interactive rebase feature
  could be broken when running in that environment.
  https://github.com/git-cola/git-cola/issues/825
  * The log window now uses an ISO-8601 timestamp, which
  avoids localized output in the log window.
  https://github.com/git-cola/git-cola/issues/817
- Development
  * The code base has been thoroughly sanitized using `pylint`, and
  travis is now running pylint over the entire project.
  * Miscellaneous improvements and code improvements.
  https://github.com/git-cola/git-cola/issues/874
* Sun Apr 29 2018 marcin.bajor@gmail.com
- Update to 3.1
- Usability, bells and whistles
  * The “Browser” widget learned to rename files using “git mv”.
  https://github.com/git-cola/git-cola/issues/239
  * The “Diff” widget learned to diff images. Side-by-side and pixel diff modes allow you to inspect changes to common images formats.
  https://github.com/git-cola/git-cola/issues/444
  https://github.com/git-cola/git-cola/pull/803
  * Git LFS and Git Annex are natively supported by the image diff viewer.
  * Git Annex operations are now included. git annex init can be performed on repositories, and git annex add can be run on untracked files from the status widget. Install git-annex to activate this feature.
  * Git LFS operations are now included. git lfs install can be performed on repositories, and git lfs track can be run on untracked files from the status widget. Install git-lfs to activate this feature.
  * The “Stash” tool learned to stash staged changes only. Select the “Stage Index” option and only staged changes will be stashed away.
  https://github.com/git-cola/git-cola/issues/413
  * The “Stash” tool learned to use vim-like navigation keyboard shortcuts, shows error messages when things go wrong, and now saves the “Stash Index” and “Keep Index” options across sessions.
  * The Edit menu’s “Copy” and “Select All” actions now forward to either the diff, status, recent, or favorites widgets, based on which widget has focus.
  * The “File” and “Edit” menu can now be activated using Alt-{f,e} hotkeys.
  https://github.com/git-cola/git-cola/issues/759
  * It was easy to accidentally trigger the first action in the Status tool’s context menu when using a quick right-click to bring up the menu. A short sub-second delay was added to ensure that the top-most action is not triggered unless enough time has passed. This prevents accidental activation of the first item (typically “Stage” or “Unstage”) without burdening common use cases.
  https://github.com/git-cola/git-cola/pull/755
  https://github.com/git-cola/git-cola/issues/643
  * The “Ctrl+S” hotkey now works for the header items in the Status tool. Selected the “Modified” header item and activating the “Stage” hotkey, for example, will stage all modified files. This works for the “Staged”, “Modified”, and “Untracked” headers. This is not enabled for the “Unmerged” header by design.
  https://github.com/git-cola/git-cola/issues/772
  * The list of “Recent” repositories previously capped the number of repositories shown to 8 repositories. This can be set to a higher value by setting the cola.maxrecent configuration variable.
  https://github.com/git-cola/git-cola/issues/752
  * The “Create Branch” dialog now prevents invalid branch names.
  https://github.com/git-cola/git-cola/issues/765
  * Updated Turkish translation.
  https://github.com/git-cola/git-cola/pull/756
  * Updated Ukrainian translation.
  https://github.com/git-cola/git-cola/pull/753
  * Updated German translation.
  https://github.com/git-cola/git-cola/pull/802
  * Updated Czech translation
  https://github.com/git-cola/git-cola/pull/792
  https://github.com/git-cola/git-cola/pull/806
  * The window title can be configured to not display the absolute path of the repository.
  https://github.com/git-cola/git-cola/issues/775
  * The “Edit Remotes” editor learned to edit remote URLS.
  * Bare repositories can now be created by selecting the “New Bare Repository…” action from the File menu.
  * The “Branches” widget learned to configure upstream branches.
  * A new git cola clone sub-command was added for cloning repositories.
- Packaging
  * The vendored qtpy library was updated to v1.3.1.
  * The macOS installation was made simpler for better compatibility with Homebrew.
  https://github.com/git-cola/git-cola/issues/636
  * The Windows installer is now much simpler. Git Cola now bundles Python and PyQt5, so users need only install the “Git for Windows” and “Git Cola” installers to get things working.
- Fixes
  * Uninitialized difftool errors will now be displayed graphically. They were previously going to the shell.
  https://github.com/git-cola/git-cola/issues/457
  * Translations marked “fuzzy” will no longer be used when translating strings.
  https://github.com/git-cola/git-cola/issues/782
  * Deleted unmerged files will now correctly use a deleted icon.
  https://github.com/git-cola/git-cola/issues/479
  * The Ctrl+C “Copy” hotkey on the diff viewer has been fixed.
  https://github.com/git-cola/git-cola/issues/767
  * The “Create Tag” dialog did not correctly handle the case when a signed tag is requested, but no message is provided, and the user chooses to create an unannotated tag instead. This convenience fallback will now properly create an unsigned, unannotated tag.
  https://github.com/git-cola/git-cola/issues/696
  * .gitconfig and .git/config values editable by the Preferences dialog (aka git cola config) will now get unset when set to an empty value. For example, setting a different user.email in the current repository, followed by a subsequent emptying of that field, would previously result in an empty string getting stored in the config. This has been fixed so that the value will now get unset in the config instead.
  https://github.com/git-cola/git-cola/issues/406
  * Spelling and typofixes.
  https://github.com/git-cola/git-cola/pull/748
  * core.commentChar is now honored when set in the local repository .git/config.
  https://github.com/git-cola/git-cola/issues/766
  * The log window was using a format string that did not display correctly in all locales. A locale-aware format is now used.
  https://github.com/git-cola/git-cola/pull/800
  * The dialog displayed when prompting for a reference could sometimes lose focus.
  https://github.com/git-cola/git-cola/pull/804
* Mon Nov 20 2017 marcin.bajor@gmail.com
- Update to 3.0
- Usability, bells and whistles
  * Updated Simplified Chinese translation.
  https://github.com/git-cola/git-cola/pull/726
  * Updated Ukranian translation.
  https://github.com/git-cola/git-cola/pull/723
  * New Czech translation.
  https://github.com/git-cola/git-cola/pull/736
  https://github.com/git-cola/git-cola/pull/737
  https://github.com/git-cola/git-cola/pull/740
  https://github.com/git-cola/git-cola/pull/743
  * The "name" field in the "Create Tag" dialog now includes autocompletion, which makes it easy to see which tags currently exist.
  * git cola now has configurable toolbars. Use the View -> Add toolbar menu item to add a toolbar.
  * Setting cola.expandtab to true will now expand tabs into spaces in the commit message editor. The number of spaces to insert is determined by consulting cola.tabwidth, which defaults to 8.
  * The "Copy SHA-1" hotkey is now Alt + Ctrl + C, to avoid clobbering the ability to copy text from the DAG window.
  https://github.com/git-cola/git-cola/pull/705
  * The "Prepare Commit Message" action can now be invoked via the Ctrl+Shift+Return shortcut.
  https://github.com/git-cola/git-cola/pull/707
  * The Branches pane now has a filter field that highlights branches whose names match the string entered into its text field.
  * https://github.com/git-cola/git-cola/pull/713
  * Actions that are triggered in response to button presses were being triggered when the button was pressed, rather than when it was released, which was a usability flaw. All buttons now respond when clicked rather than when pressed.
  https://github.com/git-cola/git-cola/pull/715
  * The DAG window will now only refresh when object IDs change. Previously, the DAG would redraw itself in response to inotify events, such as filesystem operations, which was disruptive when inspecting a large diff in its diff viewer. The DAG will now only redraw when the object IDs corresponding to its query input changes. Furthermore, when redrawing, the scrollbar positions are retained to minimize disruption to the viewport contents.
  https://github.com/git-cola/git-cola/issues/620
  https://github.com/git-cola/git-cola/issues/724
  * The "About" dialog now includes the SHA-1 where Git Cola was built.
  https://github.com/git-cola/git-cola/issues/530
  * The "Status" widget now has "Copy Leading Path to Clipboard" and "Copy Basename to Clipboard" actions.
  https://github.com/git-cola/git-cola/issues/435
  https://github.com/git-cola/git-cola/issues/436
  * The "Status" widget now supports custom "Copy ... to Clipboard" actions.
  https://github.com/git-cola/git-cola/issues/437
  * The main menu now has an "Edit" menu.
  https://github.com/git-cola/git-cola/issues/725
  * git dag learned to checkout commits into a detached HEAD state.
  https://github.com/git-cola/git-cola/issues/698
  * The status widget's context menus now omit actions selection-dependent actions when no file is selected.
  https://github.com/git-cola/git-cola/pull/731
  * The startup dialog now focuses the repository list so that repositories can be selected with the keyboard without mouse intervention.
  https://github.com/git-cola/git-cola/issues/741
- Fixes
  * git dag now prevents nodes from overlapping in more situations.
  https://github.com/git-cola/git-cola/pull/689
  * Adding untracked Git submodule repo directories previously ran git add submodule/ but we now call git add submodule without the trailing slash (/) to avoid staging files that belong to the submodule (which is possibly a git bug). By working around the buggy behavior we allow users to recover by issuing the appropriate git submodule add command to properly register the submodule.
  https://github.com/git-cola/git-cola/pull/681
  * We now avoid git for-each-ref --sort=version:refname on versions of git older than v2.7.0. Previously we only avoided it for versions older than v2.0.0, which was a mistake.
  https://github.com/git-cola/git-cola/pull/686
  * The error message displayed when git is not installed has been fixed.
  https://github.com/git-cola/git-cola/pull/686
  * Adding new remotes was silently broken.
  https://github.com/git-cola/git-cola/issues/684
  https://github.com/git-cola/git-cola/pull/685
  * The repo selection dialog had errors during startup when the cola.refreshonfocus feature was enabled, as reported on Ubuntu 16.04.
  https://github.com/git-cola/git-cola/issues/690
  * Restored support for PyQt 4.6 (Centos 6.8)
  https://github.com/git-cola/git-cola/issues/692
  * Switching repositories now resets the "Amend Mode" and other settings when switching.
  https://github.com/git-cola/git-cola/issues/710
  * git rebase error messages now displayed when rebasing fails or stops via the standalone git cola rebase front-end.
  https://github.com/git-cola/git-cola/issues/721
  * git cola learned to stage broken symlinks.
  https://github.com/git-cola/git-cola/issues/727
  * The "View History" feature in the Browser tool was fixed, and now disambiguates between refs and paths.
  https://github.com/git-cola/git-cola/issues/732
  * The diff editor now has better support for files with CRLF rn line endings.
  https://github.com/git-cola/git-cola/issues/730
  * cola.inotify in a repo-local config is now honored when git cola is launched from a desktop entry (git cola --prompt).
  https://github.com/git-cola/git-cola/issues/695
* Wed Jul 19 2017 marcin.bajor@gmail.com
- Update to 2.11
- Usability, bells and whistles
  * New Ukranian translation.
  https://github.com/git-cola/git-cola/pull/670
  https://github.com/git-cola/git-cola/pull/672
  * New and improved French translations.
  * The new Branches widget makes it easier to checkout, merge, push, and pull branches from a single interface.
  git cola now includes a dark icon theme. The dark icon theme can be activated either by setting the GIT_COLA_ICON_THEME environment variable to dark, by configuring cola.icontheme to dark, or by specifying –icon-theme=dark on the command line.
  https://github.com/git-cola/git-cola/pull/638
  * Autocompletion was added to the Fetch, Push, and Pull dialogs.
  * The commit message editor now remembers the “Spellcheck” setting after exiting.
  https://github.com/git-cola/git-cola/pull/645
  * git dag now uses an improved algorithm for laying out the graph, which avoids collisions under certain graph configurations, and avoids overlapping tag with commits.
  https://github.com/git-cola/git-cola/pull/648
  https://github.com/git-cola/git-cola/pull/651
  https://github.com/git-cola/git-cola/pull/654
  https://github.com/git-cola/git-cola/pull/656
  https://github.com/git-cola/git-cola/pull/659
  * git dag now remembers its column sizes across sessions.
  https://github.com/git-cola/git-cola/issues/674
  * Grep now shows a preview of the selected file’s content in a split window below the grep results.
  * Grep now includes line numbers in the preview pane’s output.
  * Edit Remotes now remembers its window settings after exiting.
  * Diff now has an option to display line numbers in the editor.
  https://github.com/git-cola/git-cola/issues/136
  * Amend Last Commit can now be triggered via the Commit menu in addition to the commit message editor’s options.
  https://github.com/git-cola/git-cola/issues/640
  * The File Browser tool was made much faster and can now operate on much larger repositories.
  https://github.com/git-cola/git-cola/issues/499
  * A new “turbo” mode was added that allows you to opt-out of operations that can slow git cola on large repositories. The turbo mode is enabled by configuring git config cola.turbo true. Turbo mode disables the background loading of Git commit messages and other details in the File Browser widget.
  * A new GitIgnore dialog allows adding custom gitignore patterns.
  https://github.com/git-cola/git-cola/pull/653
  * The spellchecker in git cola can now use an additional dictionary by configuring cola.dictionary to the path to a file containing a newline-separated list of words.
  https://github.com/git-cola/git-cola/issues/663
  * The stash, export patches, diff, and gitignore dialogs now remember their window sizes.
  * A new git cola recent sub-command was added for finding recently edited files.
  * The Fetch dialog now allows pruning remote branches.
  https://github.com/git-cola/git-cola/issues/639
  https://github.com/git-cola/git-cola/pull/680
- Fixes
  * git cola‘s spellchecker now supports the new dict-common filesystem layout, and prefers the /usr/share/dict/cracklib-small file over the /usr/share/dict/words provided on older distributions. This makes the spellchecker compatible with Arch, which does not provide a words symlink like Debian.
  https://github.com/git-cola/git-cola/issues/663
  * Properly handle the case where an existing file is untracked using the File Browser.
  * Fix a quirk where the “Create Branch” dialog sometimes required clicking twice on the radio buttons.
  https://github.com/git-cola/git-cola/pull/662
  * Fixed a focus issue to ensure that “Push”, “Fetch”, and “Pull” can be executed with the press of a single enter key after being shown.
  https://github.com/git-cola/git-cola/issues/661
  * Committing is now allowed in when resolving a merge results in no changes. This state was previously prevented by the commit message editor, which prevented users from resolving merges that result in no changes.
  https://github.com/git-cola/git-cola/pull/679
  * The filesystem monitor would sometimes emit backtraces when directories are modified. This has been fixed.
  https://bugzilla.redhat.com/show_bug.cgi?id=1438522
  * Absolute paths are now returned when querying for .git-relative paths from within a submodule, which uses .git-files. This fixes launching git cola from within a subdirectory of a submodule.
  https://github.com/git-cola/git-cola/pull/675
* Sat Jan 14 2017 marcin.bajor@gmail.com
- Removed appdata.patch
* Sat Jan 14 2017 marcin.bajor@gmail.com
- Update to 2.10
- Usability, bells and whistles
  * git cola can now invoke the .git/hooks/cola-prepare-commit-msg hook to update the commit message. This hook takes the same parameters as Git’s prepare-commit-message hook. The default path to this hook can be overridden by setting the cola.prepareCommitMessageHook configuration variable.
  http://git-cola.readthedocs.io/en/latest/git-cola.html#prepare-commit-message
  * git cola diff (and the corresponding Diff menu actions) can now launch difftool with the standard Ctrl+D hotkey. The Ctrl+E hotkey was also added for launching an editor.
  * Traditional Chinese (Taiwan) translation updates.
- Fixes
  * git cola now works when installed in non-ascii, utf8-encoded paths.
  https://github.com/git-cola/git-cola/issues/629
  * Styling issues that caused black backgrounds in various widgets when using PyQ5 on Mac OS X have been fixed.
  https://github.com/git-cola/git-cola/issues/624
  * The “Open Recent” menu action was broken and has been fixed.
  https://github.com/git-cola/git-cola/issues/634
  * Exiting git cola with a maximized main window would hang when reopened on Linux.
  https://github.com/git-cola/git-cola/issues/641
- Packaging
  * appdata.xml files are now provided at share/appdata/git-cola.xml and share/appdata/git-dag.xml for use by the Linux software gallery.
  https://people.freedesktop.org/~hughsient/appdata/
  https://github.com/git-cola/git-cola/pull/627
* Tue Nov 29 2016 marcin.bajor@gmail.com
- Update to 2.9.1
- Fixes
  * The “Open Recent” menu was updated to new bookmarks format.
  https://github.com/git-cola/git-cola/issues/628
* Thu Nov 24 2016 mailaender@opensuse.org
- improve appdata.patch install rules with upstream collaborators
* Wed Nov 23 2016 marcin.bajor@gmail.com
- Update to 2.9
- Usability, bells and whistles
  * New Polish translation thanks to Łukasz Wojniłowicz
  https://github.com/git-cola/git-cola/pull/598
  * The Bypass Commit Hooks feature now disables itself automatically when a new commit is created. The new behavior turns the option into a single-use flag, which helps prevent users from accidentally leaving it active longer than intended.
  https://github.com/git-cola/git-cola/pull/595
  * git dag learned to launch an external diff viewer on selected commits. The standard Ctrl+D shortcut can be used to view diffs.
  https://github.com/git-cola/git-cola/issues/468
  * git dag learned to launch directory diffs via git difftool –dir-diff. The Ctrl+Shift+D shortcut launches difftool in directory-diff mode.
  https://github.com/git-cola/git-cola/issues/468
  * Items in the “Favorites” list can now be renamed, which makes it easier to differentiate between several checkouts of the same repository.
  https://github.com/git-cola/git-cola/issues/599
  https://github.com/git-cola/git-cola/pull/601
  * The startup screen now includes a logo and git cola version information.
  https://github.com/git-cola/git-cola/issues/526
  * The About page was revamped to contain multiple tabs. A new tab was added that provides details about git cola‘’s dependencies. New tabs were also added for giving credit to git cola‘s authors and translators.
  * The About page can now be accessed via git cola about.
  * The “Fast-forward only” and “No fast-forward” options supported by git pull are now accessible via git cola pull.
  * Doing a forced push no longer requires selecting the remote branch.
  https://github.com/git-cola/git-cola/pull/618
  * git cola push now has an option to suppress the prompt that is shown when pushing would create new remote branches.
  https://github.com/git-cola/git-cola/issues/605
  * git dag now shows commit messages in a more readable color.
  https://github.com/git-cola/git-cola/issues/574
  * git cola browse and the status widget learned to launch the OS-specified default action for a file. When used on directories via git cola browse, or when “Open Parent Directory” is used on files, the OS-specified file browser will typically be used.
  git cola browse and the status widget learned to launch terminals.
- Fixes
  * git cola browse was not updating when expanding items.
  https://github.com/git-cola/git-cola/issues/588
  * Typofixes in comments, naming, and strings have been applied.
  https://github.com/git-cola/git-cola/pull/593
  * The inotify and win32 filesystem monitoring no longer refreshes when updates are made to ignored files.
  https://github.com/git-cola/git-cola/issues/517
  https://github.com/git-cola/git-cola/issues/516
  * The Refresh button on the actions panel no longer raises an exception when using PyQt5.
  https://github.com/git-cola/git-cola/issues/604
  * Fixed a typo in the inotify backend that is triggered when files are removed.
  https://github.com/git-cola/git-cola/issues/607
  * Fixed a typo when recovering from a failed attempt to open a repository.
  https://github.com/git-cola/git-cola/issues/606
  * git dag now properly updates itself when launched from the menubar.
  https://github.com/git-cola/git-cola/pull/613
  * If git-cola is invoked on Windows using start pythonw git-cola, a console window will briefly flash on the screen each time git cola invokes git. The console window is now suppressed.
  * We now avoid some problematic Popen flags on Windows which were breaking the git rebase feature on Windows.
  * The Save button in git dag‘s “Grab File...” feature now properly prompts for a filename when saving files.
  https://github.com/git-cola/git-cola/pull/617
- Development
  * The qtpy symlink in the source tree has been removed to allow for easier development on Windows.
  https://github.com/git-cola/git-cola/issues/626
* Sun Nov 20 2016 mailaender@opensuse.org
- install man pages
- add appdata.patch for en.opensuse.org/openSUSE:AppStore
* Wed Aug 31 2016 marcin.bajor@gmail.com
- Update to 2.8
- Usability, bells and whistles
  * git cola push learned to configure upstream branches.
  https://github.com/git-cola/git-cola/issues/563
- Fixes
  * The diffstat view is now properly updated when notifications are received via inotify filesystem monitoring.
  https://github.com/git-cola/git-cola/issues/577
  * Python3 with PyQt5 had a bug that prevented git cola from starting.
  https://github.com/git-cola/git-cola/pull/589
* Thu Aug  4 2016 marcin.bajor@gmail.com
- Fixed: git-cola can not find python-qt
* Sun Jul 31 2016 marcin.bajor@gmail.com
- Update to 2.7
- Fixes
  * When repositories stored in non-ASCII, UTF-8-encoded filesystem paths were operated upon with LC_ALL=C set in the environment, unicode errors would occur when using python2. git cola was made more robust and will now operate correctly within this environment.
  https://github.com/git-cola/git-cola/issues/581
  * Support for the GIT_WORK_TREE environment variable was fixed.
  https://github.com/git-cola/git-cola/pull/582
- Development
  * The unittest.mock module is now used instead of the original mock module when running the git cola test suite using Python3.
  https://github.com/git-cola/git-cola/issues/569
- Packaging
  * git cola is now compatible with PyQt5, PyQt4, and Pyside. git cola previously supported PyQt4 only, but will now use whichever library is available. Users are not required to upgrade at this time, but PyQt5 support can be enabled anytime by making its python modules available.
  https://github.com/git-cola/git-cola/issues/232
  NOTE: We do not yet recommend using PyQt5 because there are known exit-on-segfault bugs in Qt5 that have not yet been addressed. git cola is sensitive to this bug and is known to crash on exit when using git dag or the interactive rebase feature on PyQt5.
  https://bugreports.qt.io/browse/QTBUG-52988
  * PyQt4 is stable and there are no known issues when using it so we recommend using it until the Qt5 bugs have been resolved.
  git cola now depends on QtPy and includes a bundled copy of the qtpy library. If you are packaging git cola and would prefer to use qtpy from your distribution instead of the built-in version then use make NO_VENDOR_LIBS=1 when building git cola. This will prevent vendored libraries from being installed.
* Sun May  1 2016 marcin.bajor@gmail.com
- Update to 2.6
- Usability, bells and whistles
  * A new “Reset” sub-menu provides access to running “git reset –mixed” when resetting branch heads and “git reset –merge” when resetting worktrees.
  https://github.com/git-cola/git-cola/issues/542
  * git cola now supports linked worktrees, i.e. worktrees created by git worktree.
  https://github.com/git-cola/git-cola/issues/554
- Fixes
  * Diff highlighting is now robust to the user having diff.supressBlankEmpty=true in their git config.
  https://github.com/git-cola/git-cola/issues/541
  * The filesystem monitor now properly handles repositories that use .git-files, e.g. when using submodules.
  https://github.com/git-cola/git-cola/issues/545
  https://github.com/git-cola/git-cola/pulls/546
  * Per-repository git configuration is now properly detected when launching git cola from an application launcher.
  https://github.com/git-cola/git-cola/issues/548
  * git cola now cleans up after itself immediately to avoid leaving behind empty /tmp/git-cola-XXXXXX directories when the user uses Ctrl+C to quit the app.
  https://github.com/git-cola/git-cola/issues/566
- Packaging
  * It is now possible to install git cola to and from utf8-encoded filesystem paths. Previously, Python’s stdlib would during installation.
  https://github.com/git-cola/git-cola/issues/551
* Sun Jan  3 2016 marcin.bajor@gmail.com
- Update to 2.5
- Usability, bells and whistles
  * The icon for untracked files was adjusted to better differentiate between files and the “Untracked” header.
  https://github.com/git-cola/git-cola/issues/509
  * Ctrl+O was added as a hotkey for opening repositories.
  https://github.com/git-cola/git-cola/pull/507
  * git dag now uses consistent edge colors across updates.
  https://github.com/git-cola/git-cola/issues/512
  * git cola‘s Bookmarks widget can now be used to set a “Default Repository”. Under the hood, we set the cola.defaultrepo configuration variable. The default repository is used whenever git cola is launched outside of a Git repostiory. When unset, or when set to a bogus value, git cola will prompt for a repository, as it previously did.
  https://github.com/git-cola/git-cola/issues/513
  * git cola‘s Russian and Spanish translations were improved thanks to Vaiz and Zeioth.
  https://github.com/git-cola/git-cola/pull/514
  https://github.com/git-cola/git-cola/pull/515
  https://github.com/git-cola/git-cola/pull/523
  * git cola was translated to Turkish thanks to Barış ÇELİK.
  https://github.com/git-cola/git-cola/pull/520
  * The status view now supports launching git gui blame. It can be configured to use a different command by setting cola.blameviewer.
  https://github.com/git-cola/git-cola/pull/521
  * git dag now allows selecting non-contiguous ranges in the log widget.
  https://github.com/git-cola/git-cola/issues/468
  * Any font can now be chosen for the diff editor, not just monospace fonts.
  https://github.com/git-cola/git-cola/issues/525
- Fixes
  * xfce4-terminal and gnome-terminal are now supported when launching git mergetool to resolve merges. These terminals require that the command to execute is shell-quoted and passed as a single string argument to -e rather than as additional command line arguments.
  https://github.com/git-cola/git-cola/issues/524
  * Fixed a unicode problem when formatting the error message that is shown when gitk is not installed. We now handle unicode data in tracebacks generated by python itself.
  https://github.com/git-cola/git-cola/issues/528
  * The New repository feature was fixed.
  https://github.com/git-cola/git-cola/pull/533
  * We now use omit the extended description when creating “fixup!” commits, for consistency with the Git CLI. We now include only the one-line summary in the final commit message.
  https://github.com/git-cola/git-cola/issues/522
* Tue Oct 13 2015 marcin.bajor@gmail.com
- Update to 2.4
- Usability, bells and whistles
  * The user interface is now HiDPI-capable. git-cola now uses SVG icons, and its interface can be scaled by setting the GIT_COLA_SCALE environment variable.
  git dag now supports the standard editor, difftool, and history hotkeys. It is now possible to invoke these actions from file widget’s context menu and through the standard hotkeys.
  https://github.com/git-cola/git-cola/pull/473
- The Status tool also learned about the history hotkey. Additionally, the Alt-{j,k} aliases are also supported in the Status tool for consistency with the other tools where the non-Alt hotkeys are not available.
  https://github.com/git-cola/git-cola/pull/488
  * The File Browser tool now has better default column sizes, and remembers its window size and placement.
  * The File Browser now supports the refresh hotkey, and has better behavior when refreshing. The selection is now retained, and new and removed files are found when refreshing.
  * A new git-cola-completion.bash completion script is provided in the contrib/ directory. It must be used alongside Git’s completion script. Source it from your ~/.bashrc (or ~/.zshrc, etc) after sourcing the git-completion.bash script and you will have command-line completion support for the git cola and git dag sub-commands.
  * The “checkout” dialog now offers completion for remote branches and other git refs. This makes it easier to checkout remote branches in a detached head state. Additionally, the checkout dialog also offers completion for remote branches that have not yet been checked out, which makes it easier to create a local tracking branch by just completing for that potential name.
  https://github.com/git-cola/git-cola/issues/390
  * The “create branch” and “create tag” dialogs now save and restore their window settings.
  * The “status” widget can now be configured to use a bold font with a darker background for the header items.
  https://github.com/git-cola/git-cola/pull/506
  * The “status” widget now remembers its horizontol scrollbar position across updates. This is helpful when working on projects with long paths.
  https://github.com/git-cola/git-cola/issues/494
- Fixes
  * When using Git for Windows, a git window would appear when running Windows 8. We now pass additional flags to subprocess.Popen to prevent a git window from appearing.
  https://github.com/git-cola/git-cola/issues/477
  https://github.com/git-cola/git-cola/pull/486
  * Launching difftool with .PY in $PATHEXT on Windows was fixed.
  https://github.com/git-cola/git-cola/issues/492
  * Creating a local branch tracking a remote branch that contains slashes in its name is now properly handled.
  https://github.com/git-cola/git-cola/issues/496
  * The “Browse Other Branch” feature was broken by Python3, and is now fixed.
  https://github.com/git-cola/git-cola/issues/501
  * We now avoid long for better Python3 compatibility.
  https://github.com/git-cola/git-cola/issues/502
  * We now use Git’s default merge message when merging branches.
  https://github.com/git-cola/git-cola/issues/508
  * Miscellaneous fixes
  https://github.com/git-cola/git-cola/pull/485
- Packaging
  * git-cola’s documentation no longer uses an intersphinx link mapping to docs.python.org. This fixes warnings when building rpms using koji, where network access is prevented.
  https://bugzilla.redhat.com/show_bug.cgi?id=1231812
* Mon Aug 10 2015 marcin.bajor@gmail.com
- Update to 2.3
- Usability, bells and whistles
  * The Interactive Rebase feature now works on Windows!
  https://github.com/git-cola/git-cola/issues/463
  * The diff editor now understands vim-style hjkl navigation hotkeys.
  https://github.com/git-cola/git-cola/issues/476
  * Alt-{j,k} navigation hotkeys were added to allow changing to the next/previous file from the diff and commit editors.
  * The Rename branch menu action is now disabled in empty repositories.
  https://github.com/git-cola/git-cola/pull/475
  https://github.com/git-cola/git-cola/issues/459
  * git cola now checks unmerged files for conflict markers before staging them. This feature can be disabled in the preferences.
  https://github.com/git-cola/git-cola/issues/464
  * git dag now remembers which commits were selected when refreshing so that it can restore the selection afterwards.
  https://github.com/git-cola/git-cola/issues/480
  * “Launch Editor”, “Launch Difftool”, “Stage/Unstage”, and “Move Up/Down” hotkeys now work when the commit message editor has focus.
  https://github.com/git-cola/git-cola/issues/453
  * The diff editor now supports the Ctrl+u hotkey for reverting diff hunks and selected lines.
  * The core.commentChar Git configuration value is now honored. Commit messages and rebase instruction sheets will now use the configured character for comments. This allows having commit messages that start with # when core.commentChar is configured to its non-default value.
  https://github.com/git-cola/git-cola/issues/446
- Fixes
  * Diff syntax highlighting was improved to handle more edge cases and false positives.
  https://github.com/git-cola/git-cola/pull/467
  * Setting commands in the interactive rebase editor was fixed.
  https://github.com/git-cola/git-cola/issues/472
  * git-cola no longer clobbers the Ctrl+Backspace text editing shortcut in the commit message editor.
  https://github.com/git-cola/git-cola/issues/453
  * The copy/paste clipboard now persists after git cola exits.
  https://github.com/git-cola/git-cola/issues/484
* Tue Jun 16 2015 marcin.bajor@gmail.com
- Update to 2.2.1
- Fixes
  * Fixed the “Sign off” feature in the commit message editor.
* Mon Jun 15 2015 marcin.bajor@gmail.com
- Update to 2.2
- Usability, bells and whistles
  * Double-click will now choose a commit in the “Select commit” dialog.
  * git cola has a feature that reads .git/MERGE_MSG and friends for the commit message when a merge is in-progress. Upon refresh, git cola will now detect when a merge has completed and reset the commit message back to its previous state. It is only reset if the editor contains a message that was read from the file and has not been manually edited by the user.
  * The commit message editor’s context menu now has a “Clear...” action for clearing the message across both the summary and description fields.
  * Traditional Chinese (Taiwan) translation updates.
  * The system theme’s icons are now used whereever possible.
  https://github.com/git-cola/git-cola/pull/458
- Fixes
  * The stash viewer now uses git show --no-ext-diff to avoid running user-configured diff tools.
  * git cola now uses the setsid() system call to ensure that the GIT_ASKPASS and SSH_ASKPASS helper programs are used when pushing changes using git. The askpass helpers will now be used even when git cola is launched from a terminal.
  The behavior without setsid() is that git cola can appear to hang while pushing changes. The hang happens when git prompts the user for a password using the terminal, but the user never sees the prompt. setsid() detaches the terminal, which ensures that the askpass helpers are used.
  https://github.com/git-cola/git-cola/issues/218
  https://github.com/git-cola/git-cola/issues/262
  https://github.com/git-cola/git-cola/issues/377
  * git dag‘s file list tool was updated to properly handle unicode paths.
  * gnome-terminal is no longer used by default when cola.terminal is unset. It is broken, as was detailed in #456.
  https://github.com/git-cola/git-cola/issues/456
  * The interactive rebase feature was not always setting $GIT_EDITOR to the value of gui.editor, thus there could be instances where rebase will seem to not stop, or hang, when performing “reword” actions.
  We now set the $GIT_EDITOR environment variable when performing the “Continue”, “Skip”, and “Edit Todo” rebase actions so that the correct editor is used during the rebase.
  https://github.com/git-cola/git-cola/issues/445
* Tue Mar 31 2015 marcin.bajor@gmail.com
- Update to 2.1.2
- Usability, bells and whistles
  * Updated zh_TW translations.
  * git cola rebase now defaults to @{upstream}, and generally uses the same CLI syntax as git rebase.
  * The commit message editor now allows you to bypass commit hooks by selecting the “Bypass Commit Hooks” option. This is equivalent to passing the –no-verify option to git commit.
  https://github.com/git-cola/git-cola/issues/357
  * We now prevent the “Delete Files” action from creating a dialog that does not fit on screen.
  https://github.com/git-cola/git-cola/issues/378
  * git xbase learned to edit rebase instruction sheets that contain exec commands.
  * The diff colors are now configurable. cola.color.{text,add,remove,header} can now be set with 6-digit hexadecimal colors. See the git cola manual <https://git-cola.readthedocs.org/en/latest/git-cola.html#configuration-variables>_ for more details.
  * Improved hotkey documentation.
- Fixes
  * git cola will now allow starting an interactive rebase with a dirty worktree when rebase.autostash is set.
  https://github.com/git-cola/git-cola/issues/360
* Sun Feb  8 2015 mailaender@opensuse.org
- update to 2.1.1
  * A new “Find files” widget was added, and can be activated by using the Ctrl+t or t hotkeys.
  * A new git cola find sub-command was added for finding files.
  * git cola now remembers the text cursor’s position when staging interactively with the keyboard. This makes it easier to use the keyboard arrows to select and stage lines.
  * The completion widgets will now select the top completion item when Enter or Return are pressed.
  * You can now refresh using F5 in addition to the existing Ctrl+R hotkey.
  * git cola now passes –no-abbrev-commit to git log to override having log.abbrevCommit = true set in .gitconfig.
* Sat Jan 17 2015 mailaender@opensuse.org
- update to 2.1.0
  * git dag now forwards all unknown arguments along to git log.
  * Line-by-line interactive staging was made more robust.
  * “Bookmarks” was renamed to “Favorites”.
  * Untracked files are now displayed using a unique icon.
  * Untracked files are now assumed to be utf-8 encoded.
  * inotify expects unicode paths on Python3.
  * git dag was triggering a traceback on Fedora when parsing Git logs.
- fix rpmlint warning about missing %%build
* Sun Jan  4 2015 mailaender@opensuse.org
- Recommend optional python-send2trash module
* Sun Nov 30 2014 marcin.bajor@gmail.com
- Usability, bells and whistles
  * git cola can now create GPG-signed commits and merges.
  https://github.com/git-cola/git-cola/issues/149
  See the documentation for details about setting up a GPG agent.
  * The status widget learned to copy relative paths when Ctrl+x is pressed.
  https://github.com/git-cola/git-cola/issues/358
  * Custom GUI actions can now define their own keyboard shortcuts by setting guitool.$name.shortcut to a string understood by Qt’s QAction::setShortcut() API, e.g. Alt+x.
  See http://qt-project.org/doc/qt-4.8/qkeysequence.html#QKeySequence-2 for more details about the supported values.
  * git cola learned to rename branches.
  https://github.com/git-cola/git-cola/pull/364
  https://github.com/git-cola/git-cola/issues/278
  * git dag now has a “Show history” context menu which can be used to filter history using the selected paths.
- Fixes
  * sphinxtogithub.py was fixed for Python3.
  https://github.com/git-cola/git-cola/pull/353
  * The commit that changed how we read remotes from git remote to parsing git config was reverted since it created problems for some users.
  * Fixed a crash when using the rebase edit feature.
  https://github.com/git-cola/git-cola/issues/351
  * Better drag-and-drop behavior when dropping into gnome-terminal.
  https://github.com/git-cola/git-cola/issues/373
- Packaging
  * The git-cola-folder-handler.desktop file handler was fixed to pass validation by desktop-file-validate.
  https://github.com/git-cola/git-cola/issues/356
  * The git.svg icon was renamed to git-cola.svg, and git cola was taught to prefer icons from the desktop theme when available.
* Wed Oct  1 2014 marcin.bajor@gmail.com
- Update to version 2.0.7
- Usability, bells and whistles
  * New hotkey: Shift+Ctrl+M merges branches.
  * New hotkey: Ctrl+R refreshes the DAG viewer.
  https://github.com/git-cola/git-cola/issue/347
- Fixes
  * We now use git config to parse the list of remotes instead of parsing the output of git remote, which is a Git porcelain and should not be used by scripts.
  * Avoid “C++ object has been deleted” errors from PyQt4.
  https://github.com/git-cola/git-cola/issue/346
- Packaging
  * The make install target now uses install instead of cp.
* Mon Sep  1 2014 marcin.bajor@gmail.com
- Update to version 2.0.6
- Usability, bells and whistles
  * Updated Brazillian Portuguese translation.
  * The status and browse widgets now allow drag-and-drop into external applications.
  https://github.com/git-cola/git-cola/issue/335
  * We now show a progress bar when cloning repositories.
  https://github.com/git-cola/git-cola/issue/312
  * The bookmarks widget was simplified to not need a separate dialog.
  https://github.com/git-cola/git-cola/issue/289
  * Updated Traditional Chinese translation.
  * We now display a warning when trying to rebase with uncommitted changes.
  https://github.com/git-cola/git-cola/issue/338
  * The status widget learned to filter paths. Shift+Ctrl+s toggles the filter widget.
  https://github.com/git-cola/git-cola/issues/337
  https://github.com/git-cola/git-cola/pull/339
  * The status widget learned to move files to the trash when the send2trash module is installed.
  https://github.com/git-cola/git-cola/issues/341
  * “Recent repositories” is now a dedicated widget.
  https://github.com/git-cola/git-cola/issues/342
  * New Spanish translation thanks to Pilar Molina Lopez.
  https://github.com/git-cola/git-cola/pull/344
- Fixes
  * Newly added remotes are now properly seen by the fetch/push/pull dialogs.
  https://github.com/git-cola/git-cola/issues/343
* Wed Jul 30 2014 marcin.bajor@gmail.com
- Update to version 2.0.5
- Usability, bells and whistles
  * New Brazillian Portuguese translation thanks to Vitor Lobo.
  * New Indonesian translation thanks to Samsul Ma’arif.
  * Updated Simplified Chinese translation thanks to Zhang Han.
  * Ctrl+Backspace is now a hotkey for “delete untracked files” in the status widget.
  * Fetch/Push/Pull dialogs now use the configured remote of the current branch by default.
  https://github.com/git-cola/git-cola/pull/324
- Fixes
  * We now use os.getcwd() on Python3.
  https://github.com/git-cola/git-cola/pull/316
  https://github.com/git-cola/git-cola/pull/326
  * The Ctrl+P hotkey was overloaded to both “push” and “cherry-pick”, so “cherry-pick” was moved to Shift+Ctrl+C.
  * Custom GUI tools with mixed-case names are now properly supported.
  * “Diff Region” is now referred to as “Diff Hunk” for consistency with common terminology from diff/patch tools.
  https://github.com/git-cola/git-cola/issues/328
  * git-cola’s test suite is now portable to MS Windows.
  https://github.com/git-cola/git-cola/pull/332
* Fri Jun 27 2014 marcin.bajor@gmail.com
- Update to version 2.0.4
- Usability, bells and whistles
  * We now handle the case when inotify add_watch() fails and display instructions on how to increase the number of watches.
  https://github.com/git-cola/git-cola/issues/263
  * New and improved zh_TW localization thanks to Ｖ字龍(Vdragon).
  https://github.com/git-cola/git-cola/pull/265
  https://github.com/git-cola/git-cola/pull/267
  https://github.com/git-cola/git-cola/pull/268
  https://github.com/git-cola/git-cola/issues/269
  https://github.com/git-cola/git-cola/pull/270
  https://github.com/git-cola/git-cola/pull/271
  https://github.com/git-cola/git-cola/pull/272
  * New hotkeys: Ctrl+f for fetch, Ctrl+p for push, and Ctrl-shift-p for pull.
  * The bookmarks widget’s context menu actions were made clearer.
  https://github.com/git-cola/git-cola/issues/281
  * The term “Staging Area” is used consistently in the UI to allow for better localization.
  https://github.com/git-cola/git-cola/issues/283
  * The “Section” term is now referred to as “Diff Region” in the UI.
  https://github.com/git-cola/git-cola/issues/297
  * he localization documentation related to the LANGUAGE environment variable was improved.
  https://github.com/git-cola/git-cola/pull/293
  * The “Actions” panel now contains tooltips for each button in case the button labels gets truncated by Qt.
  https://github.com/git-cola/git-cola/issues/292
  * Custom git config-defined actions can now be run in the background by setting guitool.<name>.background to true.
- Fixes
  * We now use bold fonts instead of SmallCaps to avoid artifacts on several configurations.
  * We now pickup user.email, cola.tabwidth, and similar settings when defined in /etc/gitconfig.
  https://github.com/git-cola/git-cola/issues/259
  * Better support for unicode paths when using inotify.
  https://bugzilla.redhat.com/show_bug.cgi?id=1104181
  * Unicode fixes for non-ascii locales.
  https://github.com/git-cola/git-cola/issues/266
  https://github.com/git-cola/git-cola/issues/273
  https://github.com/git-cola/git-cola/issues/276
  https://github.com/git-cola/git-cola/issues/282
  https://github.com/git-cola/git-cola/issues/298
  https://github.com/git-cola/git-cola/issues/302
  https://github.com/git-cola/git-cola/issues/303
  https://github.com/git-cola/git-cola/issues/305
  * Viewing history from the file browser was fixed for Python3.
  https://github.com/git-cola/git-cola/issues/274
  * setup.py was fixed to install the *.rst documentation.
  https://github.com/git-cola/git-cola/issues/279
  * Patch export was fixed for Python3.
  https://github.com/git-cola/git-cola/issues/290
  * Fixed adding a bookmark with trailing slashes.
  https://github.com/git-cola/git-cola/pull/295
  * The default git dag layout is now setup so that its widgets can be freely resized on Linux.
  https://github.com/git-cola/git-cola/issues/299
  * Invalid tag names are now reported when creating tags.
  https://github.com/git-cola/git-cola/pull/296
* Mon May 26 2014 marcin.bajor@gmail.com
- Update to version 2.0.3
- Usability, bells and whistles
  * git cola no longer prompts after successfully creating a new branch.
  https://github.com/git-cola/git-cola/pull/251
  * Hitting enter on simple dialogs now accepts them.
  https://github.com/git-cola/git-cola/pull/255
- Fixes
  * git dag no longer relies on sys.maxint, which is not available in Python3.
  https://github.com/git-cola/git-cola/issues/249
  * Python3-related fixes.
  https://github.com/git-cola/git-cola/pull/254
  * Python3-on-Windows-related fixes.
  https://github.com/git-cola/git-cola/pull/250
  https://github.com/git-cola/git-cola/pull/252
  https://github.com/git-cola/git-cola/pull/253
  * Switching repositories using the bookmarks widget was not refreshing the inotify watcher.
  https://github.com/git-cola/git-cola/pull/256
  * Special commit messages trailers (e.g. “Acked-by:”) are now special-cased to fix word wrapping lines that start with “foo:”.
  https://github.com/git-cola/git-cola/issues/257
* Sun Apr 20 2014 marcin.bajor@gmail.com
- Update to version 2.0.2
- Usability, bells and whistles
  * Better inotify support for file creation and deletion.
  https://github.com/git-cola/git-cola/issues/240
  * git cola now supports the X11 Session Management Protocol and remembers its state across logout/reboot.
  https://github.com/git-cola/git-cola/issues/164
  * git cola has a new icon.
  https://github.com/git-cola/git-cola/issues/190
- Packaging
  * Building the documentation no longer requires asciidoc. We now use Sphinx for building html documentation and man pages.
- Fixes
  * Reworked the git-dag gravatar icon code to avoid a unicode error in Python 2.
  * Commit message line-wrapping was made to better match the GUI editor.
  https://github.com/git-cola/git-cola/issues/242
  * Better support for Python3 on Windows
  https://github.com/git-cola/git-cola/issues/246
- Packaging
  * git-cola no longer depends on Asciidoc for building its documentation and man-pages. We now depend on [Sphinx](http://sphinx-doc.org/) only.
* Sun Mar 16 2014 marcin.bajor@gmail.com
- Update to version 2.0.1
- Usability, bells and whistles
  * Some context menu actions are now hidden when selected files do not exist.
  https://github.com/git-cola/git-cola/issues/238
- Fixes
  * The build-git-cola.sh contrib script was improved.
  https://github.com/git-cola/git-cola/pull/235
  * Non-ascii worktrees work properly again.
  https://github.com/git-cola/git-cola/issues/234
  * The browser now guards itself against missing files.
  https://bugzilla.redhat.com/show_bug.cgi?id=1071378
  * Saving widget state now works under Python3.
  https://github.com/git-cola/git-cola/pull/236
* Mon Feb 24 2014 marcin.bajor@gmail.com
- Update to version 2.0.0
- Portability
  * git-cola now runs on Python 3 thanks to Virgil Dupras.
  https://github.com/git-cola/git-cola/pull/233
  * Python 2.6, 2.7, and 3.2+ are now supported. Python 2.5 is no longer supported.
- Fixes
  * i18n test fixes thanks to Virgil Dupras.
  https://github.com/git-cola/git-cola/pull/231
  * git-cola.app build fixes thanks to Maicon D. Filippsen.
  https://github.com/git-cola/git-cola/pull/230
  * Lots of pylint improvements thanks to Alex Chernetz.
  https://github.com/git-cola/git-cola/pull/229
* Fri Jan 31 2014 marcin.bajor@gmail.com
- Update to version 1.9.4
- Usability, bells and whistles
  * The new Bookmarks tool makes it really easy to switch between repositories.
  * There is now a dedicated dialog for applying patches. See the File -> Apply Patches menu item.
  https://github.com/git-cola/git-cola/issues/215
  * A new git cola am sub-command was added for applying patches.
- Fixes
  * Fixed a typo that caused inotify events to be silently ignored.
  * Fixed the sys.path setup for Mac OS X (Homebrew).
  https://github.com/git-cola/git-cola/issues/221
  * Lots of pylint fixes thanks to Alex Chernetz.
* Wed Dec 11 2013 marcin.bajor@gmail.com
- Update to version 1.9.3
- Usability, bells and whistles
  * git cola –amend now starts the editor in amend mode.
  https://github.com/git-cola/git-cola/issues/187
  * Multiple lines of text can now be pasted into the summary field. All text beyond the first newline will be automatically moved to the extended description field.
  https://github.com/git-cola/git-cola/issues/212
- Fixes
  * Stray whitespace in .git files is now ignored.
  https://github.com/git-cola/git-cola/issues/213
  * Fix “known incorrect sRGB profile” in staged-item.png.
  http://comments.gmane.org/gmane.linux.gentoo.devel/85066
* Fri Nov 29 2013 marcin.bajor@gmail.com
- Update to version 1.9.2
- Fixes
  * Fix a traceback when git push fails.
  https://bugzilla.redhat.com/show_bug.cgi?id=1034778
- Packaging
  * Most of the git-cola sub-packages have been removed. The only remaining packages are cola, cola.models, and cola.widgets.
  * The translation file for Simplified Chinese was renamed to zh_CN.po.
  https://github.com/git-cola/git-cola/issues/209
* Sun Oct 20 2013 mailaender@opensuse.org
- Update to version 1.9.1
  * git cola version –brief now prints the brief version number.
  * Resurrected the “make dist” target, for those that prefer to create their own tarballs.
  * Fixed the typo that broke the preferences dialog.
- Changes from 1.9.0
  * We now ship a full-featured interactive git rebase editor. The rebase todo file is edited using the git xbase script which is provided at $prefix/share/git-cola/bin/git-xbase. This script can be used standalone by setting the $GIT_SEQUENCE_EDITOR before running git rebase –interactive.
  * Fixup commit messages can now be loaded from the commit message editor.
  * Tool widgets can be locked in place by using the “Tools/Lock Layout” menu action.
  * You can now push to several remotes simultaneously by selecting multiple remotes in the “Push” dialog.
  * The grep tool learned to search using three different modes: basic regular expressions (default), extended regular expressions, and fixed strings.
  * git cola now depends on the argparse Python module. This module is part of the stdlib in Python 2.7 and must be installed separately when using Python 2.6 and below.
  * Support unicode in the output from fetch, push, and pull.
* Fri Sep 27 2013 marcin.bajor@gmail.com
- Update to version 1.8.5
- Usability, bells and whistles
  * We now detect the editor or history browser are misconfigured.
  http://github.com/git-cola/git-cola/issues/197
  https://bugzilla.redhat.com/show_bug.cgi?id=886826
  * Display of untracked files can be disabled from the Preferences dialog or by setting the gui.displayuntracked configuration variable to false.
  http://thread.gmane.org/gmane.comp.version-control.git/232683
- Fixes
  * Unicode stash names are now supported
  http://github.com/git-cola/git-cola/issues/198
  * The diffs produced when reverting workspace changes were made more robust.
* Thu Aug 29 2013 marcin.bajor@gmail.com
- Update to version 1.8.4
- Usability, bells and whistles
  * Brand new German translation thanks to Sven Claussner.
  * The “File” menu now provides a “New Repository...” menu action.
  * git dag now uses a dock-widget interface so that its widgets can be layed-out and arranged. Customizations are saved and restored the next time git dag is launched.
  * git dag now has a “Zoom Best Fit” button next alongside the “Zoom In” and “Zoom Out” buttons.
  * Ctrl+L now focuses the “Search” field in the git dag tool.
  * Right-clicking in the “diff” viewer now updates the cursor position before performing actions, which makes it much easier to click around and selectively stage sections. Previously, the current cursor position was used which meant that it required two clicks (left-click to update the position followed by right-click to get the context menu) for the desired section to be used. This is now a single right-click operation.
  * The Ctrl+D “Launch Diff Tool” action learned to automatically choose between git difftool and git mergetool. If the file is unmerged then we automatically launch git mergetool on the path, otherwise we use git difftool. We do this because git difftool is not intended to be used on unmerged paths. Automatically using git mergetool when appropriate is the most intuitive and muscle-memory-friendly thing to do.
  * You can now right-click on folders in your standard file browser and choose “Open With -> Git Cola” (Linux-only).
- Fixes
  * Python 2.6 on Mac OS X Snow Leopard does not provide a namedtuple at sys.version_info. We now avoid using that variable for better portability.
  * We now read the user’s Git configuration from ~/.config/git/config if that file is available, otherwise we use the traditional ~/.gitconfig path, just like Git itself.
  * Some edge cases were fixed when applying partial/selected diffs.
  * The diff viewer is now properly cleared when refreshing. http://github.com/git-cola/git-cola/issues/194
* Tue May  7 2013 marcin.bajor@gmail.com
- Update to version 1.8.3
- Usability, bells and whistles
  * The diff viewer now has an “Options” menu which can be used to set “git diff” options. This can be used to ignore whitespace changes or to show a change with its surrounding function as context.
  http://github.com/git-cola/git-cola/issues/150
  * git cola now remembers your commit message and will restore it when git cola is restarted.
  https://github.com/git-cola/git-cola/pull/175
  * Ctrl+M can now be used to toggle the “Amend last commit” checkbox in the commit message editor.
  https://github.com/git-cola/git-cola/pull/161
  * Deleting remote branches can now be done from the “Branch” menu.
  https://github.com/git-cola/git-cola/issues/152
  * The commit message editor now has a built-in spell checker.
- Fixes
  * We now avoid invoking external diffs when showing diffstats.
  https://github.com/git-cola/git-cola/pull/163
  * The Status tool learned to reselect files when refreshing.
  https://github.com/git-cola/git-cola/issues/165
  * git cola now remembers whether it has been maximized and will restore the maximized state when git cola is restarted.
  https://github.com/git-cola/git-cola/issues/172
  * Performance is now vastly improved when staging hundreds or thousands of files.
  * git cola was not correctly saving repo-specific configuration.
  https://github.com/git-cola/git-cola/issues/174
  * Fix a UnicodeDecode in sphinxtogithub when building from source.-
* Wed Feb 27 2013 marcin.bajor@gmail.com
- Update to version 1.8.2
- Usability, bells and whistles
  * We now automatically remove missing repositories from the “Select Repository” dialog.
  http://github.com/git-cola/git-cola/issues/145
  * A new git cola diff sub-command was added for diffing changed files.
- Fixes
  * The inotify auto-refresh feature makes it difficult to select text in the “diff” editor when files are being continually modified by another process. The auto-refresh causes it to lose the currently selected text, which is not wanted. We now avoid this problem by saving and restoring the selection when refreshing the editor.
  http://github.com/git-cola/git-cola/issues/155
  * More strings have been marked for l10n.
  http://github.com/git-cola/git-cola/issues/157
  * Fixed the Alt+D Diffstat shortcut.
  http://github.com/git-cola/git-cola/issues/159
- Fixes
  * Better error handling when cloning repositories.
  We were not handling the case where a git URL has no basename, e.g. https://git.example.com/. git cola originally rejected these URLs instead of allowing users to clone them. It now allows these URLs when they point to valid git repositories.
  Additionally, git cola learned to echo the errors reported by git clone when it fails.
  http://github.com/git-cola/git-cola/issues/156
* Sat Dec  8 2012 marcin.bajor@gmail.com
- Update to version 1.8.1
- Usability, bells and whistles
  * git-dag got a big visual upgrade.
  * Ctrl+G now launches the “Grep” tool.
  * Ctrl+D launches difftool and Ctrl+E launches your editor when in the diff panel.
  * git-cola can now be told to use an alternative language. For example, if the native language is German and we want git-cola to use English then we can create a ~/.config/git-cola/language file with “en” as its contents:
  $ echo en >~/.config/git-cola/language
  http://github.com/git-cola/git-cola/issues/140
  * A new git cola merge sub-command was added for merging branches.
  * Less blocking in the main UI
- Fixes
  * Autocomplete issues on KDE
  http://github.com/git-cola/git-cola/issues/144
- The “recently opened repositories” startup dialog did not display itself in the absence of bookmarks.
  http://github.com/git-cola/git-cola/issues/139
* Thu Aug 23 2012 marcin.bajor@gmail.com
- Update to version 1.8.0
- Usability, bells and whistles
  * git cola learned to honor .gitattributes when showing and interactively applying diffs. This makes it possible to store files in git using a non-utf-8 encoding and git cola will properly accept them. This must be enabled by settings cola.fileattributes to true, as it incurs a small performance penalt
  http://github.com/git-cola/git-cola/issues/closed#issue/96
  * git cola now wraps commit messages at 72 columns automatically. This is configurable using the cola.linebreak variable to enable/disable the feature, and cola.textwidth to configure the limit.
  http://github.com/git-cola/git-cola/issues/closed#issue/133
  * A new “Open Recent” sub-menu was added to the “File” menu. This makes it easy to open a recently-edited repository.
  http://github.com/git-cola/git-cola/issues/closed#issue/135
  * We now show a preview for untracked files when they are clicked using the Status tool.
  * A new “Open Using Default Application” action was added to the Status tool. It is activated using either Spacebar or through the context menu. This action uses xdg-open on Linux and open on Mac OS X.
  * A new “Open Parent Directory” action was added to the Status tool. It is activated using either Shift+Spacebar or through the context menu.
  * git dag learned to honor the log.date git configuration variable. This makes the date display follow whatever format the user has configured.
  * A new git cola config sub-command was added for quickly tweaking git cola‘s git configuration settings.
  * Some small usability tweaks – some user confirmation prompts were defaulting to “Cancel” when they should have been defaulting to the affirmative option instead.
- Fixes
  * Properly handle arbitrarily-named branches.
  * We went back to launching git mergetool using an xterm. The reason is that there are a couple of places where git mergetool requires a terminal for user interaction not covered by –no-prompt.
  * We now properly handle an edge case when applying short diffs at the start of a file
* Fri May 11 2012 marcin.bajor@gmail.com
- Update to version 1.7.7
- Usability, bells and whistles
  * New and improved grep mode lets you instantly find and edit files.
  * New git cola grep standalone mode.
  * Support for passing arguments to the configured editors, e.g. gvim -p This makes it possible to select multiple files in the status window and use Ctrl-e to edit them all at once.
  * Remote operations now prompt on errors only.
  * The Tab key now jumps to the extended description when editing the summary.
  * More shortcut key labels and misc. UX improvements.
- Fixes
  * Selecting an item no longer copies its filename to the copy/paste buffer. Ctrl-c or the “Copy” context-menu action can be used instead.
  * The repository monitoring feature on Windows learned to ignore changes within the ”.git” directory. Thanks to Andreas Sommer.-
* Sat Mar 24 2012 marcin.bajor@gmail.com
- Update to version 1.7.6
- git dag learned to color-code branchy edges. The edge colors change when a new branch is detected, which makes the history much easier to follow. A huge thanks to Uri Okrent for making it happen.
- New GUI for editing remote repositories.
- New git cola archive and git cola remote sub-commands.
- git cola browser learned an ‘Untrack’ command.
- The diff editor learned to staged/unstaged while amending.
- The status tool can now scroll horizontally.
- New git repositories can be created by clicking ‘New’ on the git cola –prompt startup screen.
* Thu Jan 26 2012 marcin.bajor@gmail.com
- Update to version 1.7.5
- Auto-completion was added to more tools.
- git-dag is easier to use on smaller displays – the author field elides its text which allows for a more compact display.
- Selected commits in git-dag were made more prominent and easier to see.
- ‘Create Branch’ learned to fetch remote branches and uses a background thread to do so.
- User-configured GUI tools are listed alphabetically in the ‘Actions’ menu.
- The ‘Pull’ dialog remembers the value of the ‘Rebase’ checkbox between invocations.
* Sun Jan  8 2012 marcin.bajor@gmail.com
- Update to version 1.7.4.1
- Detect Homebrew so that OS X users do not need to set PYTHONPATH.
- git-dag can export patches again.
* Thu Jan  5 2012 marcin.bajor@gmail.com
- Update to version 1.7.4
- The ‘Classic’ tool was renamed to ‘Browser’ and learned to limit history to the current branch.
- git-dag learned about gravatar and uses it to show images for commit authors.
- git-dag learned to use OpenGL for rendering resulting in much faster rendering.
- More dialogs learned vim-style keyboard shortcuts.
- The commit message editor learned better arrow key navigatio
* Wed Dec 28 2011 marcin.bajor@gmail.com
- Update to version 1.7.3
- git-cola learned a few new sub commands:
  * git cola dag
  * git cola branch
  * git cola search
- Return in the summary field jumps to the extended description.
- Ctrl+Return is now a shortcut for ‘Commit’.
- Better French translation for ‘Sign-off’.
- The ‘Search’ widget now has a much simpler and streamlined user interface.
- vim-style h,j,k,l navigation shortcuts were added to the DAG widget.
- git-dag no longer prompts for files when diffing commits if the text field contains paths.
- General user interface and performance improvements.
* Tue Dec  6 2011 marcin.bajor@gmail.com
- Update to version 1.7.2
- git-cola can now launch sub commands, e.g.:
  * git cola classic
  * git cola stash
  * git cola fetch
  * git cola push
  * git cola pull
  * git cola tag
- git-dag is more responsive when gathering tab-completions.
- Keyboard shortcuts are displayed when the ‘?’ key is pressed.
- Various keyboard shortcuts were added for improved usability.
- The status widget now lists unmerged files before modified files.
- vim-style h,j,k,l navigation shortcuts were added to the status widget.
- A ‘Recently Modified Files...’ tool was added.
- Tools can now be hidden with Alt + # (where # is a keyboard number) and focused with Shift + Alt + #.
- The syntax highlighting colors for diffs was made less intrusive.
- The commit message editor was redesigned to have a more compact and keyboard-convenient user interface.
- Keyboard shortcuts for adding a Signed-off-by (Ctrl + i) and creating a commit (Ctrl + m) were added.
- The status widget was adjusted to use less screen real-estate.
* Sat Nov 26 2011 marcin.bajor@gmail.com
- Update to version 1.7.1.1
- Fixes
  * Further enhanced the staging/unstaging behavior in the status widget.
  * Unmerged files are no longer listed as modified.
* Thu Nov  3 2011 marcin.bajor@gmail.com
- Update to version 1.7.0
* Sun Oct 23 2011 marcin.bajor@gmail.com
- Update to version 1.4.5.3
